#
# Catalyst::Action::Deserialize::XML::Opsview.pm
# Created by: Adam Jacob, Marchex, <adam@marchex.com>
# Created on: 10/12/2006 03:00:32 PM PDT
#
#
# AUTHORS:
#	Copyright (C) 2003-2011 Opsera Limited. All rights reserved
#
#    This file is part of Opsview
#
#    Opsview is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    Opsview is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Opsview; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#
package Catalyst::Action::Deserialize::XML::Opsview;
use Opsview::XML;

use strict;
use warnings;

use base 'Catalyst::Action';

use XML::LibXML;
my $parser = XML::LibXML->new;
my $opsview_rng = XML::LibXML::RelaxNG->new( location => "/usr/local/nagios/share/xml/opsview.rng" );

sub execute {
    my $self = shift;
    my ( $controller, $c, $test ) = @_;

    my $body = $c->request->body;
    if ($body) {
        my $doc;
        eval { $doc = $parser->parse_fh($body) };
        if ($@) {
            $c->stash->{result} = { status => "XML-ERROR", detail => $self->xml_message($@) };
            $c->res->status(400);
            return 1;    # We return 1 so that no changes are made by Deserialize.pm
        }
        eval { $_ = $opsview_rng->validate($doc) };
        if ($@) {
            $c->stash->{result} = { status => "XML-INVALID", detail => $self->xml_message($@) };
            $c->res->status(400);
            return 1;
        }
        my $xml = $c->model("OpsviewDB::XML")->new( { body => "$body" } );
        $xml->deserialize;

        #if ($xml->is_error) {
        #	# This part shouldn't happen because of prior validation
        #	$c->stash->{result} = { status => "XML-DESERIALISE-ERROR", detail => $xml->error };
        #	return 1;
        #}
        $c->request->data( $xml->data );
        $c->stash->{object} = $xml->object;
        $c->stash->{xml}    = $xml;
    }
    else {

        #$c->log->debug('I would have deserialized, but there was nothing in the body!');
    }
    return 1;
}

sub xml_message {
    my ( $self, $error ) = @_;
    if ( ref $error eq "XML::LibXML::Error" ) {
        return $error->{message};
    }
    else {
        return $error;
    }
}

1;
