#
# AUTHORS:
#	Copyright (C) 2003-2011 Opsera Limited. All rights reserved
#
#    This file is part of Opsview
#
#    Opsview is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    Opsview is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Opsview; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#
package Opsview::Web::Controller::Admin::Agent;

use Moose;
use namespace::autoclean;

BEGIN { extends qw/Opsview::Web::ControllerBase::Admin Opsview::Web::ControllerBase::Reorder/ }

__PACKAGE__->config(
    model_name        => 'OpsviewDB::Agent',
    title_description => "Agent",
    reorderable       => 1,
);

sub plugins : Local : Does(ACL) : RequiresRole(CONFIGUREVIEW) : ACLDetachTo(/access_denied) : {
    my ( $self, $c ) = @_;
    $c->stash( plugin_iterator => $c->model("OpsviewDB::Plugin")->retrieve_all_with_agents );
    my @agents = $c->model("OpsviewDB::Agent")->retrieve_all;
    $c->stash( agents_list   => \@agents );
    $c->stash( action_uri    => $c->uri_for("save_plugins") );
    $c->stash( disable_cache => 1 );
}

sub save_plugins : Local {
    my ( $self, $c ) = @_;
    $c->forward("/admin/check_save_access");
    my %agent;
    Opsview::AgentPlugin->truncate;
    foreach my $p ( $c->req->param ) {
        next if $p =~ /^\./;
        my @vals = $c->req->param($p);
        foreach my $v (@vals) {
            push @{ $agent{$v} }, $p;
            Opsview::AgentPlugin->create( { agentid => $v, pluginname => $p } );
        }
    }
    my @text;
    foreach my $a ( keys %agent ) {
        push @text, "Updating agent id=" . $a . ": " . join( ",", @{ $agent{$a} } );
    }
    Opsview::Auditlog->create(
        {   username => $c->user->username,
            text     => join( "; ", @text ),
        }
    );
    $c->res->redirect("plugins");
}

1;
