#
# AUTHORS:
#	Copyright (C) 2003-2011 Opsera Limited. All rights reserved
#
#    This file is part of Opsview
#
#    Opsview is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    Opsview is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Opsview; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#
package Opsview::Web::Controller::Admin::Ajax;

# Have to use JSON most of time as IE6's innerHTML does not work for
# options in pull down menus + search boxes

use strict;
use warnings;

use base qw/Catalyst::Controller Opsview::Web::Utils/;

use DateTime;
use Opsview::Reloadtime;

sub auto : Private {
    my ( $self, $c ) = @_;
    $c->stash( current_view => "JSON" );
}

sub options_for_parent_hosts : Local : Does(ACL) : RequiresRole(CONFIGUREHOSTS) : ACLDetachTo(/access_denied) : {
    my ( $self, $c ) = @_;
    my $ms = $c->req->param("monitoringserver_filter") || "";
    my $rs = $c->user->role->monitoringservers;
    if ( $rs->count ) {
        if ( $ms && $rs->search( { id => $ms } )->count > 0 ) {
        }
        else {

            # Only show for the first monitoringserver
            $ms = $rs->first->id;
        }
    }

    # TODO: Need to filter by hostgroup permissions
    my $it = $c->model("OpsviewDB::Host")->search_parents_by_filter(
        {   parents => $c->req->param("parent_filter") || "",
            monitoringserver => $ms,
        }
    );
    my $a = [];
    while ( my $p = $it->next ) {
        my $h = {};
        $h->{value} = $p->id;
        $h->{name}  = $p->name;
        push @$a, $h;
    }
    $c->stash( ResultSet => { Results => $a } );
}

sub options_for_plugins : Local : Does(ACL) : RequiresRole(CONFIGUREVIEW) : ACLDetachTo(/access_denied) : {
    my ( $self, $c ) = @_;
    my $a  = [];
    my $it = $c->model("OpsviewDB::Plugin")->search_by_agent( $c->req->param("agentid") );
    while ( my $p = $it->next ) {
        my $h = {};
        $h->{value} = $p->name;
        $h->{name}  = $p->name;
        push @$a, $h;
    }
    $c->stash( ResultSet => { Results => $a } );
}

# ACLs from the check_save_access
sub check_credit : Local {
    my ( $self, $c ) = @_;
    $c->forward("/admin/check_save_access");

    my @cmd = ( "/usr/local/nagios/bin/aql_check_credits", "-u", $c->req->param("username"), "-p", $c->req->param("password") );
    if ( $_ = $c->req->param("proxy_server") ) {
        push @cmd, "-P", $_;
    }
    $self->run_external_command( $c, \@cmd );
    $c->log->debug("Calling @cmd");
}

# ACLs from the check_save_access
sub send_test_sms : Local {
    my ( $self, $c ) = @_;
    $c->forward("/admin/check_save_access");

    my $num = $c->req->param("mobile");
    $num =~ s/ //g;    # Remove any spaces

    my $cmd = Opsview::Systempreference->sms_system->sms_command();

    require Nagios::Execute;
    $c->log->debug("Executing from send_test_sms: $cmd");
    my $executor = Nagios::Execute->new(
        $cmd,
        NAGIOS_CONTACTPAGER  => $num,
        NAGIOS_HOSTNAME      => 'This',
        NAGIOS_HOSTSTATE     => 'a test',
        NAGIOS_HOSTOUTPUT    => 'SMS message sent from Opsview',
        NAGIOS_SHORTDATETIME => 'via contact page',
    );

    local $SIG{CHLD} = 'DEFAULT';
    my ( $exit_code, $output ) = $executor->run();

    $c->log->debug("Exit code: $exit_code");
    $c->log->debug( "Execution ouput:" . $output );

    # only return first line in the body

    $output =~ s/\n.*//;

    $c->res->body( $output || "No output. Exit code $exit_code" );
}

# Sometimes this will return a blank ResultSet because the reload hasn't technically started yet
# Can either wait a bit longer before calling this from reload page, or poll if no data returned
sub reload_start_time : Local : Does(ACL) : RequiresRole(CONFIGUREVIEW) : ACLDetachTo(/access_denied) : {
    my ( $self, $c ) = @_;
    my ( $start, $duration, $end );
    my $now = time;
    $start    = Opsview::Reloadtime->in_progress;
    $duration = Opsview::Reloadtime->average_duration;
    if ( $start && $duration ) {
        $end = DateTime->from_epoch( epoch => $start->epoch + $duration, time_zone => "local" );
        $c->stash(
            ResultSet => {
                start_time      => $start->hms,
                end_time        => $end->hms,
                call_time_epoch => $now,
            }
        );
    }
}

sub autocomplete_odw_hostname : Local : Does(ACL) : RequiresRole(CONFIGUREVIEW) : ACLDetachTo(/access_denied) : {
    my ( $self, $c ) = @_;
    my $search = "%" . $c->req->param("host") . "%";
    my @hosts  = $c->model("OdwDB::Host")->search_like(
        name => $search,
        { order_by => 'name', }
    );

    #my @names = map { $_->name } @hosts;
    my @names;
    foreach my $host (@hosts) {
        my $name = $host->name;
        push( @names, $name ) if ( !scalar( grep( /^$name$/, @names ) ) );
    }
    $#names = 10 if ( $#names > 10 );    # only keep first 10 entries
    $c->stash( wrapper  => "wrappers/blank" );
    $c->stash( template => "unorderedlist" );
    $c->stash( list     => \@names );
    $c->forward("View::TT");
}

sub autocomplete_odw_leaf_hostgroup : Local : Does(ACL) : RequiresRole(CONFIGUREVIEW) : ACLDetachTo(/access_denied) : {
    my ( $self, $c ) = @_;
    my $search = $c->req->param("hostgroup_add");
    $c->stash( wrapper  => "wrappers/blank" );
    $c->stash( template => "unorderedlist" );
    $c->stash( list     => $c->model("OdwDB::Host")->list_leaf_hostgroups($search) );
    $c->forward("View::TT");
}

1;
