#
# AUTHORS:
#	Copyright (C) 2003-2011 Opsera Limited. All rights reserved
#
#    This file is part of Opsview
#
#    Opsview is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    Opsview is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Opsview; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#
package Opsview::Web::Controller::Admin::Auditlog;

use Moose;
use namespace::autoclean;

BEGIN { extends 'Opsview::Web::ControllerBase::Admin' }

__PACKAGE__->config(
    model_name        => 'OpsviewSchema::Auditlogs',
    title_description => "Audit logs",
    search_column     => "text",
    default_rows      => 50,
    page_search_box   => 1,
);

# Unused
sub edit       { }
sub create_new { }
sub clone      { }
sub save_new   { }
sub save       { }
sub unique     { }
sub delete     { }

sub list : Local : Does(ACL) : RequiresRole(ADMINACCESS) : ACLDetachTo(/access_denied) : {
    my ( $self, $c ) = @_;
    $c->stash( title_description => $c->loc("ui.admin.auditlog.list.title") );
    my $search = {};
    if ( my $around_id = $c->req->param("id") ) {
        $search->{id} = { -between => [ $around_id - 20, $around_id + 20 ], };
        push @{ $c->stash->{filters} }, $c->loc( "ui.admin.auditlog.label.filter.around [_1]", $around_id );
    }
    if ( exists $c->req->params->{username} ) {
        my $username = $c->req->param("username");
        $search->{username} = $username;
        $username ||= $c->loc("ui.admin.auditlog.help.systemUsername");
        push @{ $c->stash->{filters} }, $c->loc( "ui.admin.auditlog.label.filter.username [_1]", $username );
    }
    $c->stash->{list_search_criteria} = $search;

    # Need to have next line, otherwise there's a subtle bug, probably in Class::DBI::Sweet
    # where if you click an id number, and then a name, you get a DB failure (though it looks like
    # a bindvar is missing)
    $c->stash->{page_attributes} = { disable_sql_paging => 1 };
    delete $c->stash->{title_create_string};
    $self->next::method($c);
    if ( exists $c->stash->{search_array} ) {
        my $search_string = "'" . join( "', '", @{ $c->stash->{search_array} } ) . "'";
        push @{ $c->stash->{filters} }, $c->loc( "ui.admin.auditlog.label.filter.searchString [_1]", $search_string );
    }
}
