#
# AUTHORS:
#	Copyright (C) 2003-2011 Opsera Limited. All rights reserved
#
#    This file is part of Opsview
#
#    Opsview is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    Opsview is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Opsview; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#
package Opsview::Web::Controller::Admin::Backup;

use Moose;
use namespace::autoclean;

BEGIN { extends qw/Catalyst::Controller::ActionRole/ }

sub restore : Local : Args(1) : Does(ACL) : RequiresRole(ADMINACCESS) : ACLDetachTo(/access_denied) : {
    my ( $self, $c, $reloadid ) = @_;
    if ( $c->req->method eq "GET" ) {
        $c->stash( error    => $c->loc("ui.backup.error.cannotProcessWithGet") );
        $c->stash( template => "soft_error" );
        $c->detach;
    }
    my $backup_file = Opsview::Config->backupfile($reloadid);
    unless ( -r $backup_file ) {
        $c->stash( error => $c->loc( "ui.backup.error.noBackupFileFound [_1]", $backup_file ) );
        $c->stash( template => "soft_error" );
        $c->detach;
    }
    my $backup_dt = DateTime->from_epoch( epoch => ( stat($backup_file) )[9], time_zone => "local" );
    my $backup_time = $backup_dt->ymd . " " . $backup_dt->hms;

    Opsview::Auditlog->system( $c->translate( "messages.auditlog.backup.starting [_1]", $backup_time ) );

    my $audit_text;
    {

        # We have to redirect stdout to a file, otherwise it gets passed to
        # catalyst as the headers of the response
        local $SIG{CHLD} = 'DEFAULT';
        local $SIG{PIPE} = sub { die "Error with pipe: $!" };

        my $logfile = "/usr/local/nagios/var/log/db_restore.log";
        my ( $backup, $restore_in );
        $c->log->debug("Restoring from backup_file=$backup_file");
        open( $backup, "-|", "gunzip", "-c", $backup_file ) or die "Cannot start gunzip process";
        open( $restore_in, "|-", "/usr/local/nagios/bin/db_opsview db_restore > $logfile 2>&1" ) or die "Cannot start restore process";
        while (<$backup>) {
            next if /^INSERT INTO `auditlogs`/;
            next if /^DROP TABLE IF EXISTS `auditlogs`/;
            if (/CREATE TABLE `auditlogs`/) {

                # Keep reading until a blank line to miss out the CREATE TABLE for auditlogs
                while (<$backup>) {
                    last if /^$|^--/;
                }
            }
            print $restore_in $_;
        }
        close $restore_in;
        if ( $? != 0 ) {
            $audit_text = $c->translate( "messages.auditlog.backup.failed [_1] [_2]", $backup_time, $logfile );
            $c->log->warn("Backup restore failed - see logfile $logfile");
        }
        else {
            $audit_text = $c->translate( "messages.auditlog.backup.restored [_1]", $backup_time );
        }
        close $backup or die "Error in closing $backup_file";
    }

    $c->flash->{message} = $audit_text;
    Opsview::Auditlog->system($audit_text);
    $c->res->redirect( $c->req->referer || $c->uri_for("/admin/auditlog") );
}

1;
