#
# AUTHORS:
#	Copyright (C) 2003-2011 Opsera Limited. All rights reserved
#
#    This file is part of Opsview
#
#    Opsview is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    Opsview is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Opsview; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#
package Opsview::Web::Controller::Admin::Contact;

use Moose;
use namespace::autoclean;

BEGIN { extends qw/Opsview::Web::ControllerBase::Admin/ }

# NOTE
# Any changes here may need to be replicated in Controller/User/Preference.pm
# This module cannot be used as a base there due to the zero_if_empty rules
# changing config when it shouldn't

__PACKAGE__->config(
    model_name      => 'OpsviewSchema::Contacts',
    set_many        => [qw/hostgroups servicegroups keywords/],
    set_commasep    => [qw/host_notification_options service_notification_options/],
    zero_if_empty   => [qw/all_hostgroups all_servicegroups live_feed atom_collapsed use_email use_mobile/],
    page_search_box => 1,
    page_add_new    => 1,
    have_variables  => 1,
    use_synchronise => {
        hostgroups        => [],
        servicegroups     => [],
        keywords          => [],
        all_hostgroups    => 0,
        all_servicegroups => 0,
    },
);

sub auto : Private {
    my ( $self, $c, @args ) = @_;
    $c->stash( title_description => $c->loc("ui.objecttype.contact") );
    $self->next::method( $c, @args );

    my $tabs = [ "Contact", "Notifications" ];
    $c->stash( tabs => $tabs );

    # Get a popup of the list of realms, based on Opsview::Web configuration
    $_ = $c->auth_realms;
    my $auth_realms_copy = {%$_};
    delete $auth_realms_copy->{default};
    delete $auth_realms_copy->{http};    # Remove the auth method specifically for /atom
    my $labels = {};
    foreach my $r ( keys %$auth_realms_copy ) {
        $labels->{$r} = $r;
    }
    delete $auth_realms_copy->{local};
    my @values = ("local");
    push @values, sort keys %{$auth_realms_copy};
    $c->stash( realms => { values => \@values, default => "local", labels => $labels } );

    $c->stash( authtkt_default_username => Opsview::Config::Web->web_config->{authtkt_default_username} );
    1;
}

before 'list' => sub {
    my ( $self, $c ) = @_;
    $c->stash( title_description => $c->loc("ui.admin.contact.list.title") );
};

sub menu : Local : Args(1) : Does(ACL) : RequiresRole(CONFIGUREVIEW) : ACLDetachTo(/access_denied) : {
    my ( $self, $c ) = @_;
    $c->stash( template => "menu" );
    $c->stash( wrapper  => "wrappers/menu" );
}

after 'edit_common' => sub {
    my ( $self, $c ) = @_;
    $c->forward("/common/setup_languages_list");

    # This maybe set by /user/preference. CONFIGUREVIEW allows viewing this stuff
    if ( $c->stash->{object} && $c->req->action ne "user/preference" ) {
        $c->stash( list_notificationprofiles_link  => $c->uri_for( "/admin/notificationprofile",     { contact => $c->stash->{object}->id } )->path_query );
        $c->stash( create_notificationprofile_link => $c->uri_for( "/admin/notificationprofile/new", { contact => $c->stash->{object}->id } )->path_query );
    }

    if ( $c->stash->{list_notificationprofiles_link} ) {
        push @{ $c->stash->{page_view_options_links} },
            {
            link => $c->stash->{list_notificationprofiles_link},
            name => $c->loc("ui.user.preference.action.listNotificationprofiles"),
            };
    }
};

sub meta_redirect : Private {
    my ( $self, $c, @args ) = @_;
    if ( exists $c->req->params->{".submit_and_redirect"} ) {
        $c->stash( from => $c->uri_for( "/admin/notificationprofile", { contact => $c->stash->{object}->id } )->path_query );
    }
    $self->next::method( $c, @args );
}

1;
