#
# AUTHORS:
#	Copyright (C) 2003-2011 Opsera Limited. All rights reserved
#
#    This file is part of Opsview
#
#    Opsview is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    Opsview is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Opsview; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#
package Opsview::Web::Controller::Admin::Hosttemplate;

use Moose;
use namespace::autoclean;

use Data::Dump qw(dump);

BEGIN { extends qw/Opsview::Web::ControllerBase::Admin/ }

__PACKAGE__->config(
    model_name      => 'OpsviewSchema::Hosttemplates',
    page_search_box => 1,
    page_add_new    => 1,
    use_synchronise => { servicechecks => [], },
);

sub auto : Private {
    my ( $self, $c, @args ) = @_;
    $c->stash( title_description => $c->loc("ui.objecttype.hosttemplate") );
    $self->next::method( $c, @args );
    my $tabs = [ "Host Template", "Monitors", "Management URLs" ];
    $c->stash( tabs                      => $tabs );
    $c->stash( edit_form_fields_template => "tab-wrapper" );
}

after 'edit' => sub {
    my ( $self, $c, @args ) = @_;
    $c->forward("/admin/serviceoption");
};

after 'create_new' => sub {
    my ( $self, $c, @args ) = @_;
    $c->forward("/admin/serviceoption");
};

after 'clone' => sub {
    my ( $self, $c, @args ) = @_;
    $c->forward("/admin/serviceoption");
};

before 'list' => sub {
    my ( $self, $c ) = @_;
    $c->stash( title_description => $c->loc("ui.admin.hosttemplate.list.title") );

    # This did use to work, but now with multiple host templates, this is
    # not true anymore. This means you cannot search based on hostname
    # Specifies the join if searching
    #if (my $q = $c->req->param("q")) {
    #	$c->stash->{list_search_criteria} = { "hosts.name" => [ map { "%".$_."%" } split(" ", $q) ] };
    #}
};

sub do_update {
    my ( $self, $c ) = @_;

    $c->forward("/admin/strip_blank_servicechecks");

    $self->next::method($c);
    my $obj           = $c->stash->{object};
    my $servicechecks = {};
    $c->model('OpsviewDB::Servicecheckhosttemplateexception')->search( hosttemplate => $obj->id )->delete_all;
    foreach my $key ( $c->req->param ) {
        if ( $key =~ m/^exception_(\d+)_add$/ ) {
            $c->model('OpsviewDB::Servicecheckhosttemplateexception')->create(
                {   hosttemplate => $obj,
                    servicecheck => $1,
                    args         => $c->req->params->{$key}
                }
            );
            $servicechecks->{$1}->{exception} = "(args='" . $c->req->params->{$key} . "')";
        }
    }
    $c->model('OpsviewDB::Servicechecktimedoverridehosttemplateexception')->search( hosttemplate => $obj->id )->delete_all;
    foreach my $key ( $c->req->param ) {
        if ( $key =~ m/^timedoverride_(\d+)_cmd$/ ) {
            my $timeperiod = $c->req->params->{ "timedoverride_" . $1 . "_time" };
            next unless $timeperiod;

            $c->model('OpsviewDB::Servicechecktimedoverridehosttemplateexception')->create(
                {   hosttemplate => $obj,
                    servicecheck => $1,
                    timeperiod   => $timeperiod,
                    args         => $c->req->params->{$key}
                }
            );
            $servicechecks->{$1}->{timedexception} = "(timeperiod=$timeperiod,args='" . $c->req->params->{$key} . "')";
        }
    }

    # Create audit entry - merge all exceptions together keyed by servicecheck
    my $audit_fields = $c->stash->{audit_fields};
    foreach my $sc ( keys %$servicechecks ) {
        push @$audit_fields, "servicecheck_exceptions=(id=$sc," . join( ",", values( %{ $servicechecks->{$sc} } ) ) . ")";
    }

    # Get managementurls information
    my $hash = Opsview::Web::Utils->convert_multilist_params_to_hash( $c->req->params );
    $hash->{managementurls} = [] unless exists $hash->{managementurls};    # If page doesn't return any values, then set to blank
    push @$audit_fields, dump($hash);
    $obj->update($hash);

}

before 'do_synchronise' => sub {
    my ( $self, $c, $attrs ) = @_;
    $c->forward( "/admin/convert_servicechecks_input", [$attrs] );

    my $hash = Opsview::Web::Utils->convert_multilist_params_to_hash( $attrs, { delete => 1 } );
    $attrs->{managementurls} = $hash->{managementurls} || [];
};

1;
