#
# AUTHORS:
#	Copyright (C) 2003-2011 Opsera Limited. All rights reserved
#
#    This file is part of Opsview
#
#    Opsview is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    Opsview is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Opsview; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#
package Opsview::Web::Controller::Admin::Hypergraph;

use Moose;
use namespace::autoclean;

use File::Slurp;

BEGIN { extends 'Catalyst::Controller::ActionRole' }

sub index : Path : Does(ACL) : RequiresRole(CONFIGUREVIEW) : ACLDetachTo(/access_denied) : {
    my ( $self, $c, @args ) = @_;

    # The java applet makes some requests that if given a response, it stops
    # working correctly, so ignore everything that we don't recognise rather
    # than redirect to HH status page
    if ( @args && $args[0] ne "index" ) {
        $c->res->status(401);
        $c->res->body(" ");
        $c->detach;
    }

    my $host = $c->model("OpsviewDB::Monitoringserver")->retrieve(1)->host;
    $c->stash->{center_on} = $host->name;
    $c->stash->{page_title} .= ' > ' . $c->loc('ui.admin.hypergraph.title.parentTree');
}

sub graph_data : Local : Default : Does(ACL) : RequiresRole(CONFIGUREVIEW) : ACLDetachTo(/access_denied) : {
    my ( $self, $c ) = @_;
    my @edges;
    my @nodes;
    my $type;

    my $monitoringserverhosts = $c->model("OpsviewSchema::Monitoringservers")->monitoringserverhosts_lookup;
    my $parents_lookup = $c->model("OpsviewSchema::Hosts")->calculate_parents( { monitoringserverhosts_lookup => $monitoringserverhosts } );

    foreach my $host ( $c->model("OpsviewSchema::Hosts")->all ) {
        my $parents = $parents_lookup->{ $host->id };

        my $type = "node";
        if ( $_ = $monitoringserverhosts->{ $host->id } ) {
            $type = ( $_->is_master ? "master" : "slave" );
        }
        push(
            @nodes,
            {   name  => $host->name,
                label => $host->name,
                type  => $type,

                #			title => "Go to host configuration page", # doesnt display
                link => $c->uri_for( "/admin/host/edit", $host->id ),
            }
        );

        foreach (@$parents) {
            push(
                @edges,
                {   target => $_->name,
                    source => $host->name,
                }
            );
        }
    }

    #	$c->log->_dump("nodes:",@nodes);
    #	$c->log->_dump("edges:",@edges);

    $c->stash->{nodes} = \@nodes;
    $c->stash->{edges} = \@edges;

    $c->stash->{wrapper} = "wrappers/blank";
}

sub GraphXML : Path("GraphXML.dtd") {
    my ( $self, $c, @args ) = @_;
    my $dtd     = "/usr/local/nagios/share/xml/GraphXML.dtd";
    my $content = File::Slurp::read_file($dtd);
    $c->res->body($content);
    return 1;
}

1;
