#
# AUTHORS:
#	Copyright (C) 2003-2011 Opsera Limited. All rights reserved
#
#    This file is part of Opsview
#
#    Opsview is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    Opsview is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Opsview; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#
package Opsview::Web::Controller::Admin::Keyword;

use Moose;
use namespace::autoclean;

BEGIN { extends qw/Opsview::Web::ControllerBase::Admin/ }

use Opsview::Utils qw(convert_to_arrayref);

__PACKAGE__->config(
    model_name      => 'OpsviewSchema::Keywords',
    page_search_box => 1,
    page_add_new    => 1,
    use_synchronise => {
        hosts             => [],
        servicechecks     => [],
        roles             => [],
        all_hosts         => 0,
        all_servicechecks => 0,
        public            => 0,
    },
);

sub auto : Private {
    my ( $self, $c, @args ) = @_;
    $c->stash( title_description => $c->loc("ui.objecttype.keyword") );
    $self->next::method( $c, @args );

    $c->forward( "/common/get_styles_list", ["Viewport"] );

    my $tabs = [qw(Keyword Objects)];
    $c->stash( tabs => $tabs );

    1;
}

sub create_new : Path("new") : Args(0) : Does(ACL) : RequiresRole(CONFIGUREKEYWORDS) : ACLDetachTo(/access_denied) : {
    shift->next::method(@_);
}

sub delete : Local : Args(1) : Does(ACL) : RequiresRole(CONFIGUREKEYWORDS) : ACLDetachTo(/access_denied) : {
    shift->next::method(@_);
}

sub save : Local : Args(1) : Does(ACL) : RequiresRole(CONFIGUREKEYWORDS) : ACLDetachTo(/access_denied) : {
    shift->next::method(@_);
}

sub save_new : Local : Args(0) : Does(ACL) : RequiresRole(CONFIGUREKEYWORDS) : ACLDetachTo(/access_denied) : {
    shift->next::method(@_);
}

sub edit : Local : Args(1) : Does(ACL) : RequiresRole(CONFIGUREKEYWORDS) : ACLDetachTo(/access_denied) : {
    my ( $self, $c ) = @_;
    shift->next::method(@_);
    $c->stash->{choosebox_roles} = $c->model("OpsviewSchema::Roles")->search_non_system_roles->search( { all_keywords => { '!=' => 1 } } );
    $c->stash->{all_keyword_roles} = [ $c->model("OpsviewSchema::Roles")->search( { all_keywords => 1 } ) ];
}

sub clone : Local : Args(1) : Does(ACL) : RequiresRole(CONFIGUREKEYWORDS) : ACLDetachTo(/access_denied) : {
    shift->next::method(@_);
}

sub unique : Local : Args(0) : Does(ACL) : RequiresRole(CONFIGUREKEYWORDS) : ACLDetachTo(/access_denied) : {
    shift->next::method(@_);
}

sub list : Local : Args(0) : Does(ACL) : RequiresRole(CONFIGUREKEYWORDS) : ACLDetachTo(/access_denied) : {
    my ( $self, $c ) = @_;
    $c->stash( title_description => $c->loc("ui.admin.keyword.list.title") );
    shift->next::method(@_);
}

sub ajax_servicechecks : Local : Does(ACL) : RequiresRole(CONFIGUREKEYWORDS) : ACLDetachTo(/access_denied) : {
    my ( $self, $c ) = @_;

    my $filter_by_hosts = $c->req->param(".filter_by_hosts") || 0;

    # Only need id and name column
    my $rs = $c->model("OpsviewSchema::Servicechecks")->search( {}, { cols => [qw(id name)] } );
    my @results;
    if ($filter_by_hosts) {
        my $hosts = convert_to_arrayref( $c->req->params->{"hosts"} );
        @results = $rs->list_servicechecks_by_host($hosts);
    }
    else {
        @results = $rs->search;
    }
    my $a = [];
    foreach my $sc (@results) {
        my $h = {};
        $h->{value} = $sc->id;
        $h->{name}  = $sc->name;
        push @$a, $h;
    }
    $c->stash( ResultSet => { Results => $a } );
    $c->stash( current_view => "JSON" );
}

1;
