#
# AUTHORS:
#	Copyright (C) 2003-2011 Opsera Limited. All rights reserved
#
#    This file is part of Opsview
#
#    Opsview is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    Opsview is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Opsview; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#
package Opsview::Web::Controller::Admin::Monitoringserver;

use Moose;
use namespace::autoclean;

BEGIN { extends 'Opsview::Web::ControllerBase::Admin' }

__PACKAGE__->config(
    model_name             => 'OpsviewDB::Monitoringserver',
    set_many               => [qw/hosts/],
    zero_if_empty          => [qw/activated passive/],
    draggables_list_method => "monitors_list",
    page_search_box        => 1,
    page_add_new           => 1,
);

before 'auto' => sub {
    my ( $self, $c, @args ) = @_;
    $c->stash( title_description => $c->loc("ui.objecttype.monitoringserver") );
};

before 'list' => sub {
    my ( $self, $c ) = @_;
    $c->stash( title_description => $c->loc("ui.admin.monitoringserver.list.title") );
    if ( Opsview::Config->slave_initiated ) {
        $c->stash->{slave_initiated} = 1;
    }
    $c->stash->{page_attributes} = {
        sql_method         => "join_monitors",
        statement_order    => [qw/ from where order_by limit /],
        order_by           => "me.role, me.name",
        disable_sql_paging => 1,
    };

    # Specifies the join if searching
    if ( my $q = $c->req->param("q") ) {
        $c->stash->{list_search_criteria} = { "monitors.name" => [ map { "%" . $_ . "%" } split( " ", $q ) ] };
        $c->stash->{page_attributes}->{logic} = "or";
    }
};

sub change_monitored_hosts : Local : Args(0) {
    my ( $self, $c ) = @_;
    my ( $mc, $host );

    $c->forward("/admin/check_save_access");
    if ( $c->req->param("mcid") ) {
        $mc = Opsview::Monitoringserver->retrieve( $c->req->param("mcid") );
    }
    if ( $c->req->param("hostid") ) {
        $host = Opsview::Host->retrieve( $c->req->param("hostid") );
    }

    if ( $mc && $host ) {
        my $old_monitoringserver_name = $host->monitored_by->name;
        my $new_monitoringserver_name = $mc->name;
        my $audit_text                = $c->translate( "messages.auditlog.admin.monitoringserver.movingHostToNewMonitoringserver [_1] [_2] [_3]", $host->identity_string, $old_monitoringserver_name, $new_monitoringserver_name, );
        $host->monitored_by($mc);
        $host->uncommitted(1);
        $host->update;
        Opsview::Auditlog->create(
            {   username => $c->user->username,
                text     => $audit_text,
            }
        );
        $c->stash( object => $mc );
    }
    $c->stash( template => "change_draggables" );
    $c->stash( wrapper  => "wrappers/blank" );
}

1;
