#
# AUTHORS:
#	Copyright (C) 2003-2011 Opsera Limited. All rights reserved
#
#    This file is part of Opsview
#
#    Opsview is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    Opsview is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Opsview; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#
package Opsview::Web::Controller::Admin::Notificationprofile;

use Moose;
use namespace::autoclean;

BEGIN { extends qw/Opsview::Web::ControllerBase::Admin Opsview::Web::ControllerBase::Reorder/ }

__PACKAGE__->config(
    model_name      => 'OpsviewSchema::Notificationprofiles',
    reorderable     => 1,
    page_add_new    => 1,
    set_commasep    => [qw/host_notification_options service_notification_options/],
    use_synchronise => {
        host_notification_options    => [],
        service_notification_options => [],
        all_hostgroups               => 0,
        all_servicegroups            => 0,
        all_keywords                 => 0,
        keywords                     => [],
        servicegroups                => [],
        hostgroups                   => [],
        notificationmethods          => [],
    },
);

sub auto : Private {
    my ( $self, $c, @args ) = @_;
    $c->stash( title_description => $c->loc("ui.objecttype.notificationprofile") );
    $self->next::method( $c, @args );
    my $contact_exists = 0;
    if ( my $contactid = $c->req->param("contact") ) {
        if ( my $contact = $c->model("OpsviewSchema::Contacts")->find($contactid) ) {
            $c->stash( contact           => $contact );
            $c->stash( page_view_include => "view_options_links" );
            $c->stash(
                page_view_options_links => [
                    {   link => $c->uri_for_params("new"),
                        name => $c->loc( "ui.admin.notificationprofile.title.createNewProfileForContact [_1]", $contact->name ),
                    },
                ]
            );

            if ( $c->stash->{from_user_preferences} ) {
                push @{ $c->stash->{page_view_options_links} },
                    {
                    link => $c->uri_for("/user/preference")->path . "#tab-notifications",
                    name => $c->loc("ui.user.notificationprofile.title.editMyNotificationVariables"),
                    };

                # If an object id is set for manipulation, make sure the notification profile is valid for this contact
                if ( $args[0] ) {
                    unless ( $contact->notificationprofiles->search( { id => $args[0] } )->first ) {
                        $c->detach("/access_denied");
                    }
                }
            }
            else {
                push @{ $c->stash->{page_view_options_links} },
                    {
                    link => $c->uri_for( "/admin/contact/edit", $contactid, )->path . "#tab-notifications",
                    name => $c->loc("ui.admin.notificationprofile.title.editContactNotificationVariables"),
                    };
            }

            $c->stash->{list_search_criteria} = { contactid => $contactid };
            $contact_exists++;
        }
    }
    if ($contact_exists) {

        # We always set from to go back to the list page for this contact, so that meta_refresh takes you there
        $c->stash->{from} = $c->uri_for( "/admin/notificationprofile", { contact => scalar $c->req->param("contact") } );
    }
    else {
        $c->stash( page_view_include => 0 );
    }
}

sub list : Local : Args(0) : Does(ACL) : RequiresRole(CONFIGUREVIEW) : ACLDetachTo(/access_denied) {
    my ( $self, $c ) = @_;
    my $contact = $c->stash->{contact};
    unless ($contact) {
        $c->stash( error => $c->loc("messages.contact.notExist") );
        $c->detach("/soft_error");
    }
    $self->next::method($c);
}

# Override unique because the constraint is duplicate names per contact
sub unique : Local : Arg(0) : Does(ACL) : RequiresRole(CONFIGUREVIEW) : ACLDetachTo(/access_denied) {
    my ( $self, $c ) = @_;
    my $dups   = 0;
    my $params = { %{ $c->req->params } };
    my $cid    = delete $params->{contact};
    foreach my $p ( keys %$params ) {
        my $v = $c->req->param($p);
        if ( defined $v && $c->stash->{model_class}->has_column($p) && !$c->stash->{model_class}->search( { contactid => $cid, $p => $v } )->count ) {
            $dups++;
        }
    }
    $c->stash( ResultSet => ( $dups == 0 ? 0 : 1 ) );
    $c->stash( output => "json" );
}

1;
