#
# AUTHORS:
#	Copyright (C) 2003-2011 Opsera Limited. All rights reserved
#
#    This file is part of Opsview
#
#    Opsview is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    Opsview is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Opsview; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#
package Opsview::Web::Controller::Admin::Report::WeeklyAvailabilityKeywordCriticalStates;

# This controller is a bit different from others. Basically this is a subclass of O::W::C::Admin::Report
# and has a lot of the same options. But we need different controllers and templates
# because the pages are different
#
# Over time, this could all be within the same controller with options defining it, possible at auto time
# but this looks like the most flexible way for the moment
#
# Note the base is O::W::C::Admin::Report and that the model name is ReportsDB::Report

use strict;
use warnings;
use MRO::Compat;

use base qw/
    Opsview::Web::Controller::Admin::Report
    /;

__PACKAGE__->config(
    model_name        => 'ReportsDB::Report',
    title_description => "Reports",
    zero_if_empty     => [ qw/scheduled auto_null_annotation/, ],
);

sub clone { }

sub auto : Private {
    my ( $self, $c, @args ) = @_;
    $self->maybe::next::method( $c, @args );
    push @{ $c->stash->{additional_template_paths} }, $c->path_to( 'root', 'admin', 'report' )->stringify;
}

sub edit : Local {
    my ( $self, $c, @args ) = @_;
    $c->stash( tabs => [qw(Report Attributes Schedule Annotations)] );
    $self->maybe::next::method( $c, @args );
}

# NULL
sub custom_setup : Private {
    my ( $self, $c ) = @_;
}

sub save : Local : Args(1) {
    my ( $self, $c, @args ) = @_;
    $c->stash( from => $c->uri_for("/admin/report") );
    $self->maybe::next::method( $c, @args );
}

1;
