#
# AUTHORS:
#	Copyright (C) 2003-2011 Opsera Limited. All rights reserved
#
#    This file is part of Opsview
#
#    Opsview is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    Opsview is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Opsview; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#
package Opsview::Web::Controller::Admin::Role;

use Moose;
use namespace::autoclean;

BEGIN { extends qw/Opsview::Web::ControllerBase::Admin Opsview::Web::ControllerBase::Reorder/ }

__PACKAGE__->config(
    model_name      => 'OpsviewSchema::Roles',
    set_many        => [qw/accesses monitoringservers/],
    reorderable     => 1,
    page_search_box => 1,
    page_add_new    => 1,
    use_synchronise => {
        accesses             => [],
        hostgroups           => [],
        monitoringservers    => [],
        access_hostgroups    => [],
        access_servicegroups => [],
        access_keywords      => [],
        all_hostgroups       => 0,
        all_servicegroups    => 0,
        all_keywords         => 0,
    },
);

before 'auto' => sub {
    my ( $self, $c, @args ) = @_;
    $c->stash( title_description => $c->loc("ui.objecttype.role") );
};

after 'auto' => sub {
    my ( $self, $c, @args ) = @_;
    my $tabs = [ "Role", "Access", "Objects" ];
    if ( $c->stash->{object} && $c->stash->{object}->id < 10 ) {
        pop @$tabs;
    }
    $c->stash( tabs => $tabs );
};

before 'list' => sub {
    my ( $self, $c ) = @_;
    $c->stash( title_description => $c->loc("ui.admin.role.list.title") );

    # Order the roles based on system ones which cannot be deleted first
    $c->stash->{page_attributes} = {
        "+select" => [ \"IF(id<10,id,10+priority) AS sysid" ],
        order_by  => "sysid",
    };
};

before 'reorder' => sub {
    my ( $self, $c ) = @_;

    # Don't allow reordering of system roles
    $c->stash->{list_search_criteria} = { "id" => { ">=" => 10 } };
};

1;
