#
# AUTHORS:
#	Copyright (C) 2003-2011 Opsera Limited. All rights reserved
#
#    This file is part of Opsview
#
#    Opsview is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    Opsview is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Opsview; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#
package Opsview::Web::Controller::Admin::Servicegroup;

use Moose;
use namespace::autoclean;

BEGIN { extends qw/Opsview::Web::ControllerBase::Admin/ }

__PACKAGE__->config(
    model_name             => 'OpsviewSchema::Servicegroups',
    draggables_list_method => 'servicechecks',
    default_rows           => 100,
    page_search_box        => 1,
    page_add_new           => 1,
    use_synchronise        => {},
);

before 'auto' => sub {
    my ( $self, $c, @args ) = @_;
    $c->stash( title_description => $c->loc("ui.objecttype.servicegroup") );
};

before 'list' => sub {
    my ( $self, $c ) = @_;
    $c->stash( title_description => $c->loc("ui.admin.servicegroup.list.title") );
};

# This used to have its own list method, so that searches would
# work against the servicecheck name as well as the servicegroup name
# However, this caused two problems:
#  * if the servicegroup had no servicechecks, then it wouldn't get listed
#  * with mysql 5.0.51, the GROUP BY me.id, me.name would mean the display order was by id
# Since this isn't a killer feature, we remove this to just do standard listing

sub change_services : Local : Args(0) {
    my ( $self, $c ) = @_;
    my ( $sg, $service );

    $c->forward("/admin/check_save_access");

    my $objecttype = $c->req->param("objecttype");

    if ( $c->req->param("sgid") ) {
        $sg = Opsview::Servicegroup->retrieve( $c->req->param("sgid") );
    }
    if ($objecttype) {
        my $class = "Opsview::" . ucfirst($objecttype);
        if ( $c->req->param("objectid") ) {
            $service = $class->retrieve( $c->req->param("objectid") );
        }
    }

    if ( $sg && $service ) {
        my $audit_text = $c->translate( "messages.auditlog.servicegroup.movingServicecheck [_1] [_2] [_3]", $service->identity_string, $service->servicegroup->name, $sg->name );
        $service->servicegroup($sg);
        $service->uncommitted(1) if $service->can("uncommitted");
        $service->update;
        Opsview::Auditlog->create(
            {   username => $c->user->username,
                text     => $audit_text,
            }
        );
        $c->stash( object => $sg );
    }
    $c->stash( template => "change_draggables" );
    $c->stash( wrapper  => "wrappers/blank" );
}

sub services : Local : Does(ACL) : AllowedRole(CONFIGUREVIEW) : AllowedRole(CONFIGUREHOSTS) : ACLDetachTo(/access_denied) : {
    my ( $self, $c, $id ) = @_;
    my $proxied_object;
    if ( $_ = $c->req->param("host") ) {
        unless ( $c->user->can_configurehost($_) ) {
            $c->forward("/access_denied");
        }
        $proxied_object = Opsview::Host->retrieve($_);
        $c->stash->{via} = "host";
    }
    elsif ( $_ = $c->req->param("hosttemplate") ) {
        $proxied_object = Opsview::Hosttemplate->retrieve($_);
        $c->stash->{via} = "hosttemplate";
    }
    $c->stash( proxied_object => $proxied_object );
    $c->stash( wrapper        => "wrappers/blank" );
}

1;
