#
# AUTHORS:
#	Copyright (C) 2003-2011 Opsera Limited. All rights reserved
#
#    This file is part of Opsview
#
#    Opsview is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    Opsview is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Opsview; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#
package Opsview::Web::Controller::Admin::Snmptraprule;

use Moose;
use namespace::autoclean;

BEGIN { extends qw/Opsview::Web::ControllerBase::Admin Opsview::Web::ControllerBase::Reorder/ }

__PACKAGE__->config(
    model_name   => 'OpsviewDB::Snmptraprule',
    reorder_info => "Reorder the rules as desired. When a rule matches, all processing stops.",
    reorderable  => 1,
    page_add_new => 1,
);

sub auto : Private {
    my ( $self, $c, @args ) = @_;
    $c->stash( title_description => $c->loc("ui.objecttype.snmptraprule") );
    $c->forward("/common/nagios_states");
    $self->next::method( $c, @args );    # Need this so edit/3 will pick up 3
    if ( my $scid = $c->req->param("servicecheck") ) {
        if ( my $sc = $c->model("OpsviewDB::Servicecheck")->retrieve($scid) ) {
            $c->stash( servicecheck => $sc );
            $self->set_page_view_options( $c, $c->loc( "ui.admin.snmptraprule.title.createNewRuleForServicecheck [_1]", $sc->name ) );
        }
        $c->stash->{list_search_criteria} = { servicecheck => $scid };
    }
    else {
        $c->stash( page_view_include => 0 );
    }
    return 1;
}

before 'list' => sub {
    my ( $self, $c ) = @_;
    $c->stash( title_description => $c->loc("ui.admin.snmptraprule.list.title") );

    # Need to check for existence of servicecheck before listing rules for this servicecheck
    my $servicecheck = $c->stash->{servicecheck};
    unless ($servicecheck) {
        $c->stash( error => $c->loc("messages.servicecheck.notExist") );
        $c->detach("/soft_error");
    }
    if ( $servicecheck->checktype->id != 4 ) {
        $c->stash( error => $c->loc( "messages.servicecheck.notSnmpTrapType [_1]", $servicecheck->name ) );
        $c->detach("/soft_error");
    }
};

after 'save' => sub {
    my ( $self, $c, @args ) = @_;
    $c->stash->{object}->servicecheck->uncommitted(1);
    $c->stash->{object}->servicecheck->update;
};

after 'set_order' => sub {
    my ( $self, $c, @args ) = @_;
    my $class = $c->model( $self->model_name );

    my $id = $c->req->param("list[]");
    my $s  = $class->retrieve($id)->servicecheck;
    $s->uncommitted(1);
    $s->update;
};

# Override unique because the constraint is duplicate names per servicecheck
sub unique : Local : Arg(0) : Does(ACL) : RequiresRole(CONFIGUREVIEW) : ACLDetachTo(/access_denied) : {
    my ( $self, $c ) = @_;
    my $dups   = 0;
    my $params = { %{ $c->req->params } };
    my $scid   = delete $params->{servicecheck};
    foreach my $p ( keys %$params ) {
        my $v = $c->req->param($p);
        if ( defined $v && $c->stash->{model_class}->has_column($p) && !$c->stash->{model_class}->search( { servicecheck => $scid, $p => $v } )->count ) {
            $dups++;
        }
    }
    $c->stash( ResultSet => ( $dups == 0 ? 0 : 1 ) );
    $c->stash( output => "json" );
}

1;
