#
# AUTHORS:
#	Copyright (C) 2003-2011 Opsera Limited. All rights reserved
#
#    This file is part of Opsview
#
#    Opsview is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    Opsview is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Opsview; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#
package Opsview::Web::Controller::Admin::Status;

use Moose;
use namespace::autoclean;

BEGIN { extends 'Catalyst::Controller::ActionRole' }

sub auto : Private {
    my ( $self, $c ) = @_;

    $c->stash( additional_template_paths => [ $c->path_to( 'root', $c->action->namespace )->stringify, $c->path_to( 'root', 'admin' )->stringify ] );
    push( @{ $c->stash->{stylesheets} }, 'admin.css' );
    return 1;
}

sub opsview : Local : Does(ACL) : RequiresRole(RELOADACCESS) : ACLDetachTo(/access_denied) {
    my ( $self, $c ) = @_;
    $c->res->headers->content_type("text/xml");

    $c->forward("get_configuration_status_information");

    my $output = Opsview::Nagios->web_status;

    my $configuration_status = $c->stash->{configuration_status};

    $output =~ s%</opsview>%<configuration>$configuration_status</configuration></opsview>%;

    $c->res->body($output);
}

sub get_configuration_status_information : Private {
    my ( $self, $c ) = @_;

    my $uncommitted = $c->model("OpsviewSchema::Metadata")->find("uncommitted")->value;
    my $configuration_status = ( $uncommitted || !Opsview->all_committed ) ? "pending" : "uptodate";

    $c->stash( configuration_status => $configuration_status );
}

1;
