#
# AUTHORS:
#	Copyright (C) 2003-2011 Opsera Limited. All rights reserved
#
#    This file is part of Opsview
#
#    Opsview is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    Opsview is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Opsview; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#
package Opsview::Web::Controller::Admin::Systempreference;

use Moose;
use namespace::autoclean;

BEGIN { extends qw/Opsview::Web::ControllerBase::Admin/ }

__PACKAGE__->config(

    # not sure why, but the model_name can't be OpsviewDB
    model_name      => 'OpsviewSchema::Systempreferences',
    use_synchronise => {
        log_notifications          => 0,
        log_service_retries        => 0,
        log_host_retries           => 0,
        log_event_handlers         => 0,
        log_passive_checks         => 0,
        daemon_dumps_core          => 0,
        date_format                => 0,
        soft_state_dependencies    => 0,
        enable_odw_import          => 0,
        enable_full_odw_import     => 0,
        updates_includemajor       => 0,
        send_anon_data             => 0,
        show_timeline              => 0,
        smart_hosttemplate_removal => 0,
    }
);

# Unused
sub create_new { }
sub clone      { }
sub save_new   { }
sub delete     { }
sub list       { }
sub unique     { }

sub auto : Private {
    my ( $self, $c ) = @_;
    $c->stash( title_description => $c->loc("ui.objecttype.systempreference") );
    $self->next::method( $c, 1 );
    my $tabs = [qw(Web Updates ODW Nagios)];
    foreach my $plugin ( Opsview->plugins ) {
        next unless $plugin->can("display_systempreference_tab");
        push @$tabs, $plugin->display_systempreference_tab;
    }
    $c->stash( tabs => $tabs );
}

sub redirect_to_list : Path {
    my ( $self, $c ) = @_;
    $c->forward("edit");
}

before 'edit' => sub {
    my ( $self, $c ) = @_;
    $c->stash( message => $c->loc("ui.admin.systempreference.subtitle") );
};

after 'save' => sub {
    my ( $self, $c ) = @_;
    $c->flash( message => $c->loc("ui.admin.systempreference.message.successfullySaved") );
    $c->res->redirect( $c->uri_for("/admin/systempreference") );
};

sub displaysurveydata : Local : Does(ACL) : RequiresRole(CONFIGUREVIEW) : ACLDetachTo(/access_denied) : {
    my ( $self, $c ) = @_;
    $c->forward("/admin/check_save_access");
    my $level = 1;
    if ( $c->req->param("send_anon_data") ) {
        $level = 2;
    }
    my $statdata = `/usr/local/nagios/libexec/check_opsview_update --showstats=$level`;
    $statdata =~ s/\n/<br \/>/g;
    $c->res->header( "Content-Type" => "text/html" );
    $c->res->body($statdata);
}

1;
