#
# AUTHORS:
#	Copyright (C) 2003-2011 Opsera Limited. All rights reserved
#
#    This file is part of Opsview
#
#    Opsview is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    Opsview is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Opsview; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#
package Opsview::Web::Controller::Api::Status;

use strict;
use warnings;
use base qw/Catalyst::Controller::REST/;

__PACKAGE__->config(
    default => 'application/json',
    map     => {
        'text/xml'         => "XML::Status",
        'application/json' => "JSON",
    },
);

# This handles the authentication for the status API
sub auto : Private {
    my ( $self, $c ) = @_;

    $c->req->params->{login_username} ||= $c->req->header("X-Username");
    $c->req->params->{login_password} ||= $c->req->header("X-Password");
    if ( !$c->forward("/login_api") ) {
        $c->res->status(403);
        my $text = $c->translate("messages.access.noAuthToStatusApi");
        $c->res->body($text);
        $c->detach;
    }
    1;
}

sub service : Local : ActionClass("REST") {
}

sub service_GET {
    my ( $self, $c ) = @_;
    unless ( $c->forward("/status/process_parameters") ) {
        my $text = $c->translate("messages.api.badParameters");
        $self->status_bad_request( $c, message => "$text: " . join( "; ", @{ $c->stash->{error} } ) );
        $c->detach;
    }
    my $asuser = $c->stash->{asuser};
    $self->status_ok( $c, entity => { service => $c->model("RuntimeDB::Searches")->list_services( $asuser, $c->req->params )->as_hashref } );
}

sub viewport : Local : Args(1) : ActionClass("REST") {
}

sub viewport_GET {
    my ( $self, $c, $keyword ) = @_;
    $c->req->params->{keyword}               = $keyword;
    $c->req->params->{includehandleddetails} = 1;
    $self->service_GET($c);
}

sub hostgroup : Local : ActionClass("REST") {
}

sub hostgroup_GET {
    my ( $self, $c, $hgid ) = @_;
    $hgid = 1 unless defined $hgid;
    my $hg = $c->model("RuntimeDB::Hostgroup")->retrieve($hgid);
    unless ($hg) {
        $self->status_not_found( $c, message => $c->translate( "messages.hostgroup.notFound [_1]", $hgid ) );
        $c->detach;
    }
    unless ( $c->forward("/status/process_parameters") ) {
        my $text = $c->translate("messages.api.badParameters");
        $self->status_bad_request( $c, message => "$text: " . join( "; ", @{ $c->stash->{error} } ) );
        $c->detach;
    }
    my $asuser = $c->stash->{asuser};
    $self->status_ok( $c, entity => { hostgroup => $c->model("RuntimeDB::Searches")->list_summarized_hosts_services( $asuser, { %{ $c->req->params }, hostgroupid => $hgid, summarizeon => "hostgroup" } ) }, );
}

1;
