#
# AUTHORS:
#	Copyright (C) 2003-2011 Opsera Limited. All rights reserved
#
#    This file is part of Opsview
#
#    Opsview is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    Opsview is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Opsview; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#
package Opsview::Web::Controller::Info;

use strict;
use warnings;

use base qw/Catalyst::Controller/;
use Opsview::Systempreference;

use Opsview::Wiki;

use Data::Dump qw/dump/;

sub auto : Private {
    my ( $self, $c ) = @_;

    $c->stash->{default_info} = "No comments currently entered for this item. To find out about adding URLs and formatting text see 'Formatting Help'.";

    return 1;
}

sub get_html : PathPart('info/get_html') Chained('/') Args(0) {
    my ( $self, $c ) = @_;
    my $html = $c->request->params->{content};

    if ( $html =~ /^\s*$/ ) {
        $html = $c->stash->{default_info};
    }

    $html =~ s/\&/\&amp;/g;
    $html =~ s/\>/\&gt;/g;
    $html =~ s/\</\&lt;/g;
    $html =~ s/\"/\&quot;/g;

    # disable quoting of ' as breaks italics & bold formatting
    #    $html =~ s/\'/&apos;/g;
    $c->response->body( Opsview::Wiki->convert_to_html($html) );
}

sub show_tag {
    my ( $self, $tag ) = @_;

    return "<pre>\n" . $tag . "</pre>\n" . Opsview::Wiki->convert_to_html($tag) . "\n";
}

sub syntax : PathPart('info/syntax') Chained('/') Args(0) {
    my ( $self, $c ) = @_;

    # Construct the syntax page to ensure the example formatting is seen correctly
    my $syntax = "";
    my $list   = "";

    $syntax .= '<a href="javascript:self.close()">' . "Close" . '</a>';

    $syntax .= Opsview::Wiki->convert_to_html("= Formatting Syntax =");
    $syntax .= "Brief information about how to use formating codes.";

    $syntax .= Opsview::Wiki->convert_to_html("== Titles ==");
    $syntax .= $self->show_tag("= Level 1 Title =");
    $syntax .= $self->show_tag("== Level 2 Title ==");
    $syntax .= $self->show_tag("=== Level 3 Title ===");
    $syntax .= $self->show_tag("==== Level 4 Title ====");

    $syntax .= Opsview::Wiki->convert_to_html("== Character Formatting ==");
    $syntax .= $self->show_tag("''Italic''");
    $syntax .= $self->show_tag("'''Bold'''");
    $syntax .= $self->show_tag("'''''Italic and Bold'''''");
    $syntax .= "A horizontal line is marked by\n";
    $syntax .= $self->show_tag("----");
    $syntax .= "All other text is treated as paragraph formatting.\n";

    $syntax .= Opsview::Wiki->convert_to_html("== Links ==");
    $syntax .= $self->show_tag("[http://server/link|link title]");
    $syntax .= $self->show_tag("[http://server/other/link]");

    $syntax .= Opsview::Wiki->convert_to_html("== Lists ==");
    $syntax .= Opsview::Wiki->convert_to_html("''Note:'' list items are indented by a tab or 4 spaces");

    $syntax .= Opsview::Wiki->convert_to_html("=== Unordered List ===");

    $list = "";
    $list   .= "    * " . "unordered list one" . "\n";
    $list   .= "    * " . "unordered list two" . "\n";
    $syntax .= $self->show_tag($list);

    $syntax .= Opsview::Wiki->convert_to_html("=== Ordered List With Nesting ===");

    $list = "";
    $list   .= "   1. " . "ordered list" . "\n";
    $list   .= "    a. " . "nested list" . "\n";
    $list   .= "    b. " . "nested list" . "\n";
    $list   .= "   2. " . "ordered list" . "\n";
    $syntax .= $self->show_tag($list);

    $syntax .= Opsview::Wiki->convert_to_html("== Code block ==");
    $syntax .= "Code blocks are lines of text each indented by 6 spaces" . "\n";
    $list = "";
    $list   .= "      for (my \$var = 0; \$var < 100 ; \$var ++ ) {\n";
    $list   .= "        print \"var = \$var\\n\";\n";
    $list   .= "      }\n";
    $syntax .= $self->show_tag($list);

    $syntax .= Opsview::Wiki->convert_to_html("== Escaped characters ==");
    $syntax .= 'The following are escaped at input time: &lt;, &gt;, &amp;, &quot;' . "\n<br/>\n";

    $syntax .= '<a href="javascript:self.close()">Close</a>';

    #$c->response->body( ( Opsview::Wiki->convert_to_html($syntax) ) );
    $c->stash->{wrapper}    = "wrappers/miniwindow";
    $c->stash->{template}   = "popup";
    $c->stash->{page_title} = "Formatting Help";
    $c->stash->{content}    = $syntax;
}

1;
