#
# AUTHORS:
#	Copyright (C) 2003-2011 Opsera Limited. All rights reserved
#
#    This file is part of Opsview
#
#    Opsview is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    Opsview is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Opsview; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#
package Opsview::Web::Controller::NmisCGI;

use strict;
use warnings;

#use base qw/CatalystX::Controller::WrapCGI/;
use base qw/Opsview::Web::ControllerBase::WrapCGI/;

__PACKAGE__->config( cgi_base_path => '/usr/local/nagios/nmis/cgi-bin', );

sub path_prefix {'cgi-nmis'}

sub auto : Private {
    my ( $self, $c ) = @_;

    return 0 unless $c->forward('/authenticate');

    unless ( $c->user_exists && $c->user->has_access("ADMINACCESS") ) {
        $c->stash( template => "access_denied" );
        Opsview::Auditlog->create( { username => $c->user->username, text => $c->translate("messages.auditlog.accessDeniedNoAdmin") } );
        return 0;
    }

    $c->stash( template => 'cgi_output' );
    return 1;
}

sub nmiscgi : Path('nmiscgi.pl') {
    my ( $self, $c ) = @_;
    $self->cgi_to_response( $c => "nmiscgi.pl" );
}

sub admin : Path('admin.pl') {
    my ( $self, $c ) = @_;
    $self->cgi_to_response( $c => "admin.pl" );
}

sub view : Path('view.pl') {
    my ( $self, $c ) = @_;
    $self->cgi_to_response( $c => "view.pl" );
}

sub summary : Path('summary.pl') {
    my ( $self, $c ) = @_;
    $self->cgi_to_response( $c => "summary.pl" );
}

sub view_event : Path('view-event.pl') {
    my ( $self, $c ) = @_;
    $self->cgi_to_response( $c => "view-event.pl" );
}

sub reports : Path('reports.pl') {
    my ( $self, $c ) = @_;
    $c->req->method('GET');    # Need this as reports.pl only expects GETs
    $self->cgi_to_response( $c => "reports.pl" );
}

1;
