#
# AUTHORS:
#	Copyright (C) 2003-2011 Opsera Limited. All rights reserved
#
#    This file is part of Opsview
#
#    Opsview is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    Opsview is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Opsview; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#
package Opsview::Web::Controller::REST::Config::Host;

use Moose;
use namespace::autoclean;

BEGIN { extends 'Opsview::Web::ControllerBase::Config' }

__PACKAGE__->config( model_name => "OpsviewSchema::Hosts", );

sub objecttype : Chained("/rest/config_root") : CaptureArgs(0) : PathPart("host") : Does(ACL) : RequiresRole(CONFIGUREHOSTS) : ACLDetachTo(/access_denied) {
    my ( $self, $c ) = @_;
    my $rs = $c->stash->{resultset};

    # Catalyst magic! Restrict all subsequent calls to only the objects this user is allowed to see based on role
    my $hg_paths = [ map { $_->matpath . "%" } $c->user->role->hostgroups ];
    $rs = $rs->search( { "hostgroup.matpath" => { "-like" => $hg_paths } }, { join => "hostgroup", order_by => "me.name", prefetch => [ "icon", "hostgroup" ] } );
    $c->stash->{resultset} = $rs;

    # Need to override here, because otherwise "name" is ambiguous
    $c->req->params->{"s.me.name"} = delete $c->req->params->{"s.name"} if exists $c->req->params->{"s.name"};
}

1;
