#
# AUTHORS:
#	Copyright (C) 2003-2011 Opsera Limited. All rights reserved
#
#    This file is part of Opsview
#
#    Opsview is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    Opsview is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Opsview; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#
package Opsview::Web::Controller::REST::Config::Hostgroup;

use Moose;
use namespace::autoclean;

BEGIN { extends 'Opsview::Web::ControllerBase::Config' }

__PACKAGE__->config( model_name => "OpsviewSchema::Hostgroups", );

# The API will return back the entire list of host groups
# Even though the web UI is only meant to see the list of leaves
sub objecttype : Chained("/rest/config_root") : CaptureArgs(0) : PathPart("hostgroup") : Does(ACL) : RequiresRole(CONFIGUREVIEW) : ACLDetachTo(/access_denied) {
    my ( $self, $c ) = @_;

    if ( $c->req->params->{order} && $c->req->params->{order} eq "dependency" ) {
        my $rs = $c->stash->{resultset};

        # This needs to be ordered by lft, rather than level (LENGTH(matpath)), like servicechecks.
        # The reason is that you cannot have host groups with duplicate leaf names and trying to sync
        # based on level could cause duplicate leaf names if, eg, /Opsview/Live/UK and /Opsview/Test/UK.
        # Listing by lft goes down a whole branch first which means that leaves will not get duplicated
        $c->stash->{resultset} = $rs->search( {}, { order_by => "lft" } );
    }
}

1;
