#
# AUTHORS:
#	Copyright (C) 2003-2011 Opsera Limited. All rights reserved
#
#    This file is part of Opsview
#
#    Opsview is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    Opsview is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Opsview; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#
package Opsview::Web::Controller::REST::Status::Viewport;

use Moose;
use namespace::autoclean;

BEGIN { extends 'Catalyst::Controller::ActionRole', 'Opsview::Web::ControllerBase::REST' }

sub apply_restrictions : Private {
    my ( $self, $c ) = @_;

    my $rs = $c->model("RuntimeSchema::OpsviewViewports");

    # Note: Need to check for users as this could be called anonymously
    # API requires login, but this is also called from /viewport
    if ( $c->user_exists ) {
        my $user = $c->user;
        if ( $user->can_view_all || $user->role->all_keywords ) {

            # Everything
        }
        else {

            # Note: There is no join with contacts table - this should be true when a reload occurs so we avoid the unnecessary join
            $c->model("OpsviewSchema::Keywords")->set_roleid( $user->role->id );
            $rs = $rs->search( { "-or" => [ { "keywordroles_or_public.roleid" => $user->role->id }, { "opsview_keyword.public" => 1 } ] }, { join => { "opsview_keyword" => "keywordroles_or_public" } } );
        }
    }
    else {

        # Filter by public only
        $rs = $rs->search( { "opsview_keyword.public" => 1 }, { join => "opsview_keyword" } );
    }

    $c->stash( rs => $rs );
}

sub viewport_root : Chained("/rest/status_root") : PathPart("viewport") : CaptureArgs(0) {
}

sub viewport_one : Chained("viewport_root") : PathPart("") : Args(1) : ActionClass("REST") : Does(ACL) : AllowedRole(VIEWSOME) : AllowedRole(VIEWALL) : ACLDetachTo(/access_denied) {
}

sub viewport_one_GET : Private {
    my ( $self, $c, $viewport ) = @_;

    $self->apply_restrictions($c);

    # Confirm this viewport is allowed
    my $found = $c->stash->{rs}->search( { keyword => $viewport } )->count;
    unless ($found) {
        $c->res->status(403);
        $c->stash( "rest" => { message => "No access to keyword $viewport" } );
        $c->detach;
    }

    # No need to apply_restrictions because we force the query to filter by keyword
    # which we have already confirmed above is valid
    $c->stash->{rs} = $c->model("RuntimeSchema::OpsviewHostObjects");
    my $h = $c->stash->{status_params} ||= { %{ $c->req->params } };
    $h->{keyword} = $viewport;
    $c->stash->{status_params} = $h;

    $c->forward("/rest/status/service/_service_GET");
}

sub viewport : Chained("viewport_root") : PathPart("") : Args(0) : ActionClass('REST') : Does(ACL) : AllowedRole(VIEWSOME) : AllowedRole(VIEWALL) : ACLDetachTo(/access_denied) {
    shift->apply_restrictions(shift);
}

# Can't have permission on viewport_GET because this could be called from a public page
sub viewport_GET : Private {
    my ( $self, $c ) = @_;

    my $rs     = $c->stash->{rs};
    my $args   = $c->stash->{status_params} || { %{ $c->req->params } };
    my $result = $rs->list_summary($args);

    $c->stash( 'rest' => $result );
}

1;
