#
# AUTHORS:
#	Copyright (C) 2003-2011 Opsera Limited. All rights reserved
#
#    This file is part of Opsview
#
#    Opsview is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    Opsview is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Opsview; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#
package Opsview::Web::Controller::SideNav;

use base qw/Catalyst::Controller/;

use Clone qw(clone);

__PACKAGE__->mk_accessors(qw/menus/);

# Generate the modules menu items
sub menus_list {
    my ( $self, $c ) = @_;
    my $rs = $c->model("OpsviewSchema::Modules")->search( { enabled => 1 }, { order_by => "priority" } );
    my @entries = ();
    while ( my $item = $rs->next ) {
        my $h = { url => $item->url, name => $item->name };
        $h->{access} = $item->access if $item->access;
        if ( $item->url =~ m%http://www.opsview.com% ) {
            $h->{module_external_link} = 1;
        }
        push @entries, $h;
    }
    my $dynamic_modules = { name => "Modules", entries => \@entries };

    # Get the yml configuration for menus and insert the modules on in
    my $menu_list = $self->menus;
    my $found     = 0;
    my $new_menus = [];
    foreach my $e (@$menu_list) {
        if ( $e->{name} eq "Modules" ) {
            $found++;
            $e = $dynamic_modules;
        }
        push @$new_menus, $e;
    }

    # Otherwise add after ALERTS
    unless ($found) {
        $new_menus = [];
        foreach my $e (@$menu_list) {
            push @$new_menus, $e;
            if ( $e->{name} eq "Alerts" ) {
                $found++;
                push @$new_menus, $dynamic_modules;
            }
        }
    }

    # Otherwise add to end
    unless ($found) {
        push @$new_menus, $dynamic_modules;
    }
    return $new_menus;
}

sub setup_data : Private {
    my ( $self, $c ) = @_;

    my %sidenav_data;

    # This is not required anymore for the new UI, but leave commented out for moment
    #my %saved_sections;
    #if ( my $cookie = $c->req->cookie('navigator_sections') ) {
    #    if ( $cookie->value ) {
    #        $saved_sections{$_}++ for split( /\./, $cookie->value );
    #    }
    #}

    my @menus;

    my $menus_list = $self->menus_list($c);

    foreach my $menu_proto (@$menus_list) {

        # Must clone this as we change the values further down
        my %menu = %{ clone($menu_proto) };

        my $ident = lc( $menu{'name'} );
        $ident =~ s/[\. ]//g;
        $menu{'ident'} = "section-${ident}";

        #$menu{'display'} = 1 if $saved_sections{$ident};
        my $display_name = $c->loc("ui.menu.section.$ident");

        # Need to keep this here, because someone may have custom sections
        $display_name = $menu{name} if ( $display_name eq "ui.menu.section.$ident" );
        $menu{name} = $display_name;
        if ( $menu{custom} ) {

            # Short circuit for search box
            push( @menus, \%menu );
            next;
        }

        my $defaultaccess   = $menu{defaultaccess};
        my @allowed_entries = ();
        foreach my $entry ( @{ $menu{entries} } ) {
            my $access = $entry->{access} || $defaultaccess;

            # Need to check user_exists because of some public pages
            if ( !$access || $c->user_exists && $c->user->has_access($access) ) {
                push @allowed_entries, $entry;
            }
            else {

                # Ignore this entry
                next;
            }
            my $url = $entry->{url};
            next if $entry->{noproxy};
            if ( $url =~ m/^http[s]?:/xsm ) {
                $entry->{url} = $url;
            }
            elsif ( $url =~ /(.*)\?(.*)/ ) {
                $entry->{url} = $c->uri_for($1)->path . "?$2";
            }
            else {

                # Need the "" to force URI to be a scalar
                $entry->{url} = $c->uri_for($url)->path_query;
            }
            if ( $ident eq "help" ) {
                if ( $entry->{name} eq "Documentation" ) {
                    $entry->{url} = $c->config->{doc_url};
                }
            }
            my $ident = lc( $entry->{name} );
            $ident =~ s/[\. ]//g;
            my $display_name = $c->loc("ui.menu.entry.$ident");

            # Need to keep these here because of custom menu items that maybe already created
            $display_name = $entry->{name} if ( $display_name eq "ui.menu.entry.$ident" );
            $entry->{name} = $display_name;
        }

        # Any menus with no items are not added
        if (@allowed_entries) {
            $menu{entries} = \@allowed_entries;
            push( @menus, \%menu );
        }
    }

    $sidenav_data{'menus'} = \@menus;

    $c->stash( sidenav_data => \%sidenav_data );

    push( @{ $c->stash->{stylesheets} }, 'sidenav.css' );
}

sub slaves : Local {
    my ( $self, $c ) = @_;
    $c->stash( target  => "main" );             # For slaves sidenav
    $c->stash( wrapper => "wrappers/blank" );
}

1;
