#
# AUTHORS:
#	Copyright (C) 2003-2011 Opsera Limited. All rights reserved
#
#    This file is part of Opsview
#
#    Opsview is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    Opsview is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Opsview; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#
package Opsview::Web::Controller::State::Hostgroup;
use strict;
use warnings;
use MRO::Compat;
use base qw(
    Opsview::Web::ControllerBase::Menus
    Opsview::Web::ControllerBase::Chained
    Opsview::Web::ControllerBase::Detail
    Opsview::Web::ControllerBase::Downtime
);

__PACKAGE__->config( model_name => "RuntimeDB::Hostgroup", );

sub anchor : PathPart('state/hostgroup') Chained('/') CaptureArgs(0) {
    shift->common(shift);
}

sub do_detail : Private {
    my ( $self, $c ) = @_;

    my $object = $c->stash->{object};

    $c->stash( title_description => $c->loc( "ui.state.hostgroup.title.summary [_1]", $object->name ) );

    # Tried to convert to DBIx::Class, but there are some issues with Datetime inflation, different values and links not working
    # This really needs a good going over - OPS-277
    #my $rs = $c->model("RuntimeSchema::OpsviewHosts")->search( { "hostgroup.matpath" => { "-like" => $object->matpath . "%" } }, { join => [qw(hostgroup hoststatus)] } );
    #if ( $c->user->has_access("VIEWSOME") ) {
    #    $rs = $rs->search( { "contacts.contactid" => $c->user->id }, { join => "contacts" } );
    #}
    #$c->stash->{total_hosts} = $rs->count;
    my @hosts = $object->list_all_hosts( $c->user );
    $c->stash->{total_hosts} = scalar(@hosts);

    #$rs = $c->model("RuntimeSchema::OpsviewHostServices")->search( { "hostgroup.matpath" => { "-like" => $object->matpath . "%" } }, { join => [ "servicestatus", { host => "hostgroup" } ] }, );
    #if ( $c->user->has_access("VIEWSOME") ) {
    #    $rs = $rs->search( { "contacts.contactid" => $c->user->id }, { join => "contacts" } );
    #}
    #$c->stash->{total_services} = $rs->count;
    my @services = $object->list_all_services( $c->user );
    $c->stash->{total_services} = scalar(@services);

    #$rs = $c->model("RuntimeSchema::NagiosScheduleddowntimes")->search(
    #    {   "downtime_type"     => 2,
    #        "hostgroup.matpath" => { "-like" => $object->matpath . "%" }
    #    },
    #    { join => { host => "hostgroup" }, }
    #);
    #if ( $c->user->has_access("VIEWSOME") ) {
    #    $rs = $rs->search( { "contacts.contactid" => $c->user->id }, { join => "contacts" } );
    #}
    #$c->stash->{downtime_hosts} = $rs->count;
    my @downtime_hosts = $object->list_all_hosts_with_downtime( $c->user );
    $c->stash->{downtime_hosts} = scalar(@downtime_hosts);

    #$rs = $c->model("RuntimeSchema::NagiosScheduleddowntimes")->search(
    #    {   "downtime_type"     => 2,
    #        "hostgroup.matpath" => { "-like" => $object->matpath . "%" }
    #    },
    #    { join => { host => "hostgroup" }, }
    #);
    #if ( $c->user->has_access("VIEWSOME") ) {
    #    $rs = $rs->search( { "contacts.contactid" => $c->user->id }, { join => "contacts" } );
    #}
    #$c->stash->{downtime_services} = $rs->count;
    my @downtime_services = $object->list_all_services_with_downtime( $c->user );
    $c->stash->{downtime_services} = scalar(@downtime_services);

    #my @downtimes = $object->list_all_hostgroup_downtime_by_comment;
    #$rs = $c->model("RuntimeSchema::NagiosScheduleddowntimes")->search(
    #    { "hostgroup.matpath" => { "-like" => $object->matpath . "%" } },
    #    {   join     => { host_objects => { host => "hostgroup" } },
    #        group_by => [qw(comment_data entry_time)],
    #        order_by => [qw(comment_data scheduled_start_time)],
    #    }
    #);
    #if ( $c->user->has_access("VIEWSOME") ) {
    #    $rs = $rs->search( { "contacts.contactid" => $c->user->id }, { join => "contacts" } );
    #}
    #my @downtimes = $rs->search;
    #$c->stash( downtimes => \@downtimes );
    #my @downtimes = $object->list_all_hostgroup_downtime_by_comment( $c->user );
    $c->stash( downtime_params => { "hostgroupid" => $object->id, rows => "all" } );
    $c->forward("/rest/downtime/downtime_GET");
    my $downtimes = $c->stash->{rest}->{list};

    $c->stash( downtimes => $downtimes );

    $self->next::method($c);
}

sub list_downtime_hosts : Chained('downtime_by_id_chained_no_auth') : Args(0) {
    my ( $self, $c ) = @_;
    $c->stash->{template} = "list_downtime_hosts";
    $c->stash( list_hosts => 1 );
    delete $c->stash->{wrapper};
}

sub list_downtime_services : Chained('downtime_by_id_chained_no_auth') : Args(0) {
    my ( $self, $c ) = @_;
    $c->stash->{template} = "list_downtime_hosts";
    $c->stash( list_hosts => 0 );
    delete $c->stash->{wrapper};
}

sub delete : Private {
    my ( $self, $c ) = @_;
    $c->stash->{hostgroups} = [ $c->model("RuntimeSchema::OpsviewHostgroups")->find( $c->stash->{object}->id ) ];
    $c->forward("/rest/downtime/downtime_DELETE");
    $c->res->redirect( $c->uri_for( "/state/hostgroup", $c->stash->{object}->id, "detail" ) );
    $c->flash( message => $c->loc( "ui.downtime.help.downtimeDeletedFor [_1]", $c->stash->{object}->name ) );
}

1;
