#
# AUTHORS:
#	Copyright (C) 2003-2011 Opsera Limited. All rights reserved
#
#    This file is part of Opsview
#
#    Opsview is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    Opsview is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Opsview; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#
package Opsview::Web::Controller::State::Service;
use strict;
use warnings;
use MRO::Compat;
use base qw(
    Opsview::Web::ControllerBase::Menus
    Opsview::Web::ControllerBase::Chained
    Opsview::Web::ControllerBase::State
    Opsview::Web::ControllerBase::Detail
    Opsview::Web::ControllerBase::Downtime
);

__PACKAGE__->config( model_name => "RuntimeDB::Service", );

sub anchor : PathPart('state/service') Chained('/') CaptureArgs(0) {
    shift->common(shift);
}

# rework chain for hostname/servicename combinations
sub by_name : PathPart('name') Chained('anchor') CaptureArgs(2) {
    my ( $self, $c, $hostname, $servicename ) = @_;
    my $it = $c->model( $self->model_name )->search(
        {   hostname    => $hostname,
            servicename => $servicename,
        }
    );
    unless ( $it->count ) {
        $c->stash( error => "Service $servicename on host $hostname not found" );
        $c->detach("/soft_error");
    }
    $c->stash( objects => [ $it->data ] );
    $c->stash( object  => $it->first );
}

# action chains
sub save_downtime_by_name_chained_end : PathPart('save') : Chained('downtime_by_name_chained') : Args(0) {
    shift->save(@_);
}

sub delete_downtime_by_name_chained_end : PathPart('delete') : Chained('downtime_by_name_chained') : Args(0) {
    shift->delete(@_);
}

sub deleteall_downtime_by_name_chained_end : PathPart('delete_all') : Chained('downtime_by_name_chained') : Args(0) {
    shift->delete_all(@_);
}

sub do_detail : Private {
    my ( $self, $c ) = @_;
    my $object = $c->stash->{object};
    $c->stash( title_description => $c->loc( "ui.state.service.title.summary [_1] [_2]", $object->name, $object->host_object_id->name ) );

    #my @downtimes = $object->list_all_service_downtime_by_comment;

    $c->stash( downtime_params => { "serviceid" => $object->id, rows => "all" } );
    $c->forward("/rest/downtime/downtime_GET");
    my $downtimes = $c->stash->{rest}->{list};

    $c->stash( downtimes => $downtimes );
    $self->next::method($c);
}

sub delete : Private {
    my ( $self, $c ) = @_;
    $c->stash->{services} = [ $c->model("RuntimeSchema::OpsviewHostServices")->find( $c->stash->{object}->id ) ];
    $c->forward("/rest/downtime/downtime_DELETE");
    $c->res->redirect( $c->uri_for( "/status/service", { host => $c->stash->{object}->hostname } ) );
    $c->flash( message => $c->loc( "ui.downtime.help.downtimeDeletedFor [_1]", join( "::", $c->stash->{object}->hostname, $c->stash->{object}->name ) ) );
}

sub host_service : Local {
    my ( $self, $c, $service_id ) = @_;

    if ( !$service_id ) {
        $c->res->redirect( $c->uri_for("/status/hostgroup") );
    }

    my $svc = $c->model('RuntimeDB::Service')->retrieve($service_id);

    if ($svc) {
        $c->res->redirect( $c->uri_for( $svc . "/change" ) );
    }
    else {
        $c->res->redirect( $c->uri_for("/status/hostgroup") );
    }
}

1;
