#
# AUTHORS:
#	Copyright (C) 2003-2011 Opsera Limited. All rights reserved
#
#    This file is part of Opsview
#
#    Opsview is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    Opsview is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Opsview; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#
# Need this so that anything under /status is protected
package Opsview::Web::Controller::Status;

use strict;
use warnings;

use base qw/Catalyst::Controller/;
use Opsview::Utils qw(convert_to_arrayref);

sub auto : Private {
    my ( $self, $c, $id ) = @_;

    $c->stash( additional_template_paths => [ $c->path_to( 'root', 'status' )->stringify ] );

    $c->stash( page_view_include => "view_options_links" );
    $c->stash(
        page_view_options_links => [
            {   link => $c->uri_for_params("/status/service/acknowledge")->path_query,
                name => $c->loc("ui.status.label.massAcknowledgements"),
            },
            {   link => $c->uri_for_params("/status/service/recheck")->path_query,
                name => $c->loc("ui.status.label.massRechecks"),
            }
        ]
    );

    my $filters = {};
    my $params  = $c->req->params;
    if ( my $this_state = $params->{host_filter} ) {
        $filters->{host_filter} = $c->loc("ui.status.label.$this_state");
    }
    if ( my $this_state = $params->{filter} ) {
        $filters->{filter} = $c->loc("ui.status.label.$this_state");
    }
    if ( $_ = $params->{includeunhandledhosts} ) {
        $filters->{includeunhandledhosts} = $c->loc("ui.message.yes");
    }
    if ( exists $params->{host_state} ) {
        $_ = convert_to_arrayref( $params->{host_state} );
        $filters->{host_state} = join( ", ", map { $c->loc_host_state($_) } @$_ );
    }
    if ( exists $params->{state} ) {
        $_ = convert_to_arrayref( $params->{state} );
        $filters->{state} = join( ", ", map { $c->loc_service_state($_) } @$_ );
    }
    if ( $_ = $params->{host} ) {
        $_ = convert_to_arrayref($_);
        $filters->{host} = join( ", ", @$_ );
    }
    if ( $_ = $params->{servicecheck} ) {
        $_ = convert_to_arrayref($_);
        $filters->{servicecheck} = join( ", ", @$_ );
    }
    if (%$filters) {
        $c->stash( filter_options => $filters );
    }

    return $c->forward('/authenticate');
}

# Common end for all status pages
sub end : Private {
    my ( $self, $c ) = @_;
    if ( defined $c->req->param("output") && $c->req->param("output") eq "ajax" ) {
        $c->stash( wrapper => "wrappers/blank" );
    }
    else {
        $c->forward("/refresh_page");
    }
    $c->detach("/end");
}

sub redirect_to_hostgroup_1 : Path {
    my ( $self, $c ) = @_;
    $c->res->redirect( $c->uri_for("/status/hostgroup") );
}

# This is a URL for listing MRTG hosts
sub network_traffic : Local {
    my ( $self, $c ) = @_;
    push @{ $c->stash->{stylesheets} }, "admin.css";
    my @mrtg       = $c->model("OpsviewSchema::Hosts")->search( { use_mrtg => 1, enable_snmp => 1 } );
    my $user       = $c->user;
    my @validhosts = grep { $_ = $user->has_host_access($_) } @mrtg;
    my @hosts      = sort { $a->name cmp $b->name } @validhosts;
    $c->stash( list => \@hosts );
    $c->stash->{page_title} .= ' > ' . $c->loc('ui.mrtg.title');
    $c->stash( page_view_include => 0 );
}

# Returns true if no errors found, otherwise false
sub process_parameters : Private {
    my ( $self, $c ) = @_;
    my $errors = [];
    if ( $c->req->params->{asuser} && $c->user->can_view_all ) {
        my $ascontactname = $c->req->params->{asuser};
        my $ascontact = $c->model("OpsviewSchema::Contacts")->search( { name => $ascontactname } )->next;
        if ($ascontact) {
            $c->stash( asuser => $ascontact );
        }
        else {
            push @$errors, $c->loc( "messages.contact.notFound [_1]", $ascontactname );
        }
    }
    else {
        $c->stash( asuser => $c->user );
    }
    if (@$errors) {
        $c->stash( error => $errors );
        return 0;
    }
    return 1;
}

1;
