#
# AUTHORS:
#	Copyright (C) 2003-2011 Opsera Limited. All rights reserved
#
#    This file is part of Opsview
#
#    Opsview is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    Opsview is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Opsview; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#
package Opsview::Web::Controller::Status::Host;

use base qw/Catalyst::Controller/;

# Sets up permissions
sub auto : Private {
    my ( $self, $c ) = @_;
    $c->forward("/rest/status/host/apply_restrictions");
}

sub default : Path {
    my ( $self, $c ) = @_;

    my $heading_list = $c->stash->{heading_list} = [];
    push @$heading_list, $c->loc("ui.status.host.label.summary");

    if ( $_ = $c->req->param("hostgroupid") ) {

        # This needs to be filtered by permissions
        my $hg = $c->model("RuntimeSchema::OpsviewHostgroups")->search( { id => $_ } )->first;
        if ($hg) {
            $c->stash( hostgroup => $hg );
            $c->stash( breadcrumbs => $c->forward( "/status/hostgroup/breadcrumbs", [$hg] ) );
            push @$heading_list, $c->loc("ui.objecttype.hostgroup") . ": " . $hg->name;
        }
    }

    my $params = { %{ $c->req->params } };
    $c->stash( status_params => $params );
    $c->forward("/rest/status/host/host_GET");
    $c->stash( status_data => $c->stash->{rest} );

    $c->stash( template => "host" );
}

sub breadcrumb : Private {
    my ( $self, $c, $host ) = @_;
    my @params_to_delete = qw(servicecheck hostgroupid host_filter host_state state);
    my $context          = $c->req->params->{context} || "";
    my %extra_params     = ();
    if ( $context ne "alerts" ) {
        push @params_to_delete, qw(filter);
    }
    else {
        %extra_params = ( includeunhandledhosts => 1, filter => "unhandled" );
    }
    return {
        name => $host->name,
        uri  => $c->uri_for_params_status( "/status/service", { host => $host->name, %extra_params }, \@params_to_delete ),
    };
}

1;
