#
# AUTHORS:
#	Copyright (C) 2003-2011 Opsera Limited. All rights reserved
#
#    This file is part of Opsview
#
#    Opsview is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    Opsview is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Opsview; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#
package Opsview::Web::Controller::Status::Hostgroup;

use warnings;
use strict;
use base qw/Catalyst::Controller/;

# Sets up permissions
sub auto : Private {
    my ( $self, $c ) = @_;
    $c->forward("/rest/status/hostgroup/apply_restrictions");
}

# /status/hostgroup/{id}
# gets redirected to appropriate location
sub hostgroup_by_id : Path : Args(1) {
    my ( $self, $c, $hgid ) = @_;
    my $hg = $c->stash->{rs}->search( { id => $hgid }, { distinct => 1 } )->first;
    unless ($hg) {
        $c->stash( error => $c->loc( "messages.hostgroup.notFound [_1]", $hgid ) );
        $c->detach("/soft_error");
    }
    if ( $hg->is_leaf ) {
        $c->res->redirect( $c->uri_for_params_status( "/status/host", { hostgroupid => $hg->id } ) );
    }
    else {
        $c->res->redirect( $c->uri_for( "/status/hostgroup", { parentid => $hgid } ) );
    }
}

# Old style URL of form:
# /status/hostgroup/name/$hostgroup_name
sub old_urls : Path : Args(2) {
    my ( $self, $c, $hgid, $arg ) = @_;

    if ( defined $hgid && $hgid eq "name" ) {

        # Find hostgroup by name
        my $hg = $c->stash->{rs}->search( { name => $arg }, { distinct => 1 } )->first;
        unless ($hg) {
            $c->stash( error => $c->loc( "messages.hostgroup.nameNotFound [_1]", $arg ) );
            $c->detach("/soft_error");
        }
        $c->res->redirect( $c->uri_for( "/status/hostgroup", $hg->id ) );
        $c->detach;
    }
    $c->forward("/catch_all");
}

sub default : Path {
    my ( $self, $c ) = @_;

    # Short circuit - if no args set, then redirect with parentid=1
    if ( scalar keys %{ $c->req->params } == 0 ) {
        $c->res->redirect( $c->uri_for( "", { parentid => 1 } ) );
        $c->detach;
    }

    my $heading_list = $c->stash->{heading_list} = [];
    push @$heading_list, $c->loc("ui.status.hostgroup.label.summary");

    if ( $_ = $c->req->param("parentid") ) {
        my $hg = $c->stash->{rs}->search( { id => $_ }, { distinct => 1 } )->first;
        if ($hg) {
            if ( $hg->is_leaf ) {
                $c->res->redirect( $c->uri_for_params_status( "/status/host", { hostgroupid => $hg->id }, ["parentid"] ) );
                $c->detach;
            }
            $c->stash( hostgroup => $hg );
            $c->stash( breadcrumbs => $c->forward( "/status/hostgroup/breadcrumbs", [$hg] ) );
            push @$heading_list, $hg->name;
        }
    }

    my $params = { %{ $c->req->params } };
    $params->{cols} = "-matpath";
    $c->stash( status_params => $params );
    $c->forward("/rest/status/hostgroup/hostgroup_GET");
    $c->stash( status_data => $c->stash->{rest} );

    $c->stash( template => "hostgroup" );

}

sub breadcrumbs : Private {
    my ( $self, $c, $hostgroup ) = @_;
    my @names = split( ",", $hostgroup->matpath );
    my @ids   = split( ",", $hostgroup->matpathid );
    my @matpath;
    my @params_to_delete = qw(host servicecheck hostgroupid host_filter host_state state);
    my $context          = $c->req->params->{context} || "";
    my %extra_params     = ();
    if ( $context ne "alerts" ) {
        push @params_to_delete, qw(filter);
    }
    else {
        %extra_params = ( includeunhandledhosts => 1, filter => "unhandled" );
    }
    foreach my $name (@names) {
        my $id = shift @ids;
        push @matpath,
            {
            name => $name,
            uri  => $c->uri_for_params_status( "/status/hostgroup", { parentid => $id, %extra_params }, \@params_to_delete ),
            };
    }
    return \@matpath;
}

1;
