#
# AUTHORS:
#	Copyright (C) 2003-2011 Opsera Limited. All rights reserved
#
#    This file is part of Opsview
#
#    Opsview is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    Opsview is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Opsview; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#
package Opsview::Web::Controller::User::Notificationprofile;

use Moose;
use namespace::autoclean;

use Opsview::Utils qw(convert_to_arrayref);

BEGIN { extends 'Opsview::Web::Controller::Admin::Notificationprofile' }

sub auto : Private {
    my ( $self, $c, @args ) = @_;
    $c->stash->{admin_override} = 1;
    $c->stash->{help_section}   = "notificationprofile";
    $c->stash( title_description => $c->loc("ui.objecttype.preference") );

    $c->stash( from_user_preferences => 1 );

    # Line below is the magic that stops a user from changing someone else's information
    $c->req->params->{contact} = $c->user->id;
    $self->next::method( $c, @args );

    $c->stash( user_has_save_access => 1 );

    push @{ $c->stash->{additional_template_paths} }, $c->path_to( 'root', 'admin', 'notificationprofile' )->stringify;

    # Always return back to list page
    $c->stash( from => $c->uri_for("/user/notificationprofile")->path );
}

sub set_order : Local {
    my ( $self, $c, @args ) = @_;

    # Only allow notification profiles for this user
    my %valid    = map { ( $_->id => 1 ) } ( $c->user->notificationprofiles );
    my $list     = convert_to_arrayref( $c->req->params->{'list[]'} );
    my @stripped = grep { $valid{$_} } @$list;
    $c->req->params->{'list[]'} = \@stripped;

    $self->next::method( $c, @args );
}

# Remove ACLs as this is run from user perspective
sub list : Local : Args(0) {
    shift->next::method(@_);
}

sub edit : Local : Args(1) {
    shift->next::method(@_);
}

sub delete : Local : Args(1) {
    shift->next::method(@_);
}

sub create_new : Path('new') : Args(0) {
    shift->next::method(@_);
}

sub save_new : Local : Args(0) {
    shift->next::method(@_);
}

sub clone : Local : Args(1) {
    shift->next::method(@_);
}

sub save : Local : Args(1) {
    shift->next::method(@_);
}

sub unique : Local : Args(0) {
    shift->next::method(@_);
}

sub reorder : Local {
    shift->next::method(@_);
}

1;
