#
# AUTHORS:
#	Copyright (C) 2003-2011 Opsera Limited. All rights reserved
#
#    This file is part of Opsview
#
#    Opsview is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    Opsview is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Opsview; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#
package Opsview::Web::Controller::User::Preference;

use Moose;
use namespace::autoclean;

BEGIN { extends qw/Opsview::Web::Controller::Admin::Contact/ }

# Unused URLs
sub clone      { }
sub delete     { }
sub list       { }
sub save_new   { }
sub create_new { }
sub unique     { }

sub auto : Private {
    my ( $self, $c ) = @_;
    $c->stash->{admin_override}      = 1;
    $c->stash->{help_section}        = "contact";
    $c->stash->{via_user_preference} = 1;
    $c->stash( title_description => $c->loc("ui.objecttype.preference") );

    # Line below is the magic that stops a user from changing someone else's information
    $self->next::method( $c, $c->user->id );

    # Need this to remove actions from Opsview::Web::Controller::Admin::Contact
    delete $c->stash->{page_view_options_links};

    # Allow user to change own information
    $c->stash( user_has_save_access => 1 );

    # Delete search box
    $c->stash( page_search_box => 0 );

    push @{ $c->stash->{additional_template_paths} }, $c->path_to( 'root', 'admin', 'contact' )->stringify;
}

before 'edit_common' => sub {
    my ( $self, $c ) = @_;
    if ( $c->user->has_access("NOTIFYSOME") ) {
        $c->stash( list_notificationprofiles_link  => $c->uri_for("/user/notificationprofile")->path_query );
        $c->stash( create_notificationprofile_link => $c->uri_for("/user/notificationprofile/new")->path_query );
    }
    else {
        $c->stash( no_notifications_for_user => 1 );
    }
};

sub redirect_to_list : Path {
    my ( $self, $c ) = @_;
    $c->forward("edit");
}

sub edit : Local {
    my ( $self, $c ) = @_;
    if ( $c->user->has_access("CONFIGUREVIEW") && $c->user->has_access("CONFIGURESAVE") ) {
        $c->res->redirect( $c->uri_for( "/admin/contact/edit", $c->user->id ) );
    }
    else {
        $c->stash( message => $c->loc("ui.user.preference.subtitle") );
        $self->next::method( $c, $c->user->id );
        $c->forward("/common/setup_languages_list");
    }
}

sub do_synchronise {
    my ( $self, $c, $attrs ) = @_;

    my $allowed_params = {
        description => 1,
        language    => 1,
        fullname    => 1,
        variables   => 1,
    };
    if ( $c->user->has_access("PASSWORDSAVE") ) {
        $allowed_params->{password} = 1;
    }

    my $valid_params = {};

    # Only allow specific parameters to be passed through
    # to guard against hacks
    foreach my $p (%$attrs) {
        if ( $allowed_params->{$p} ) {
            $valid_params->{$p} = $attrs->{$p};
        }
        elsif ( $p =~ /^variables\[.*]$/ ) {
            $valid_params->{$p} = $attrs->{$p};
        }
    }
    $valid_params->{id} = $c->user->id;

    $self->next::method( $c, $valid_params );
}

sub save : Local {
    my ( $self, $c ) = @_;
    $self->next::method( $c, $c->user->id );
    $c->flash( message => $c->loc("ui.user.preference.message.successfullySaved") );
    if ( exists $c->req->params->{".submit_and_redirect"} ) {
        $c->res->redirect( $c->uri_for( "/user/notificationprofile", { contact => $c->stash->{object}->id } )->path_query );
    }
    else {
        $c->res->redirect( $c->uri_for("/user/preference") );
    }
}

sub send_test_sms : Local {
    my ( $self, $c ) = @_;
    $c->forward("/admin/ajax/send_test_sms");
}

1;
