#
# AUTHORS:
#	Copyright (C) 2003-2011 Opsera Limited. All rights reserved
#
#    This file is part of Opsview
#
#    Opsview is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    Opsview is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Opsview; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#
package Opsview::Web::Controller::Viewport::Summarystyle::tagcloud;

use strict;
use warnings;
use HTML::TagCloud;

use base qw/Catalyst::Controller/;

__PACKAGE__->config( description => "Tag cloud", );

sub override : Private {
    my ( $self, $c ) = @_;
    my $tag_cloud = HTML::TagCloud->new(
        levels          => 10,
        anchor_callback => sub {
            my $t = shift;
            qq{<a href="$t->{url}" class="$t->{class}" title="$t->{title}">$t->{name}</a>};
        },
    );
    foreach my $keyword ( @{ $c->stash->{status_data}->{list} } ) {
        my $failures = ( $keyword->{services}->{critical}->{unhandled} || 0 ) + ( $keyword->{services}->{warning}->{unhandled} || 0 ) + ( $keyword->{services}->{unknown}->{unhandled} || 0 );
        my $services = $keyword->{services}->{total};
        $tag_cloud->add( $keyword->{name}, $c->uri_for( "/viewport", $keyword->{name} )->path, $services, { class => $keyword->{computed_state}, title => $c->loc( "ui.viewportsummary.style.tagcloud.unhandledFailures [_1]", $failures ) }, );
    }
    $c->stash( tag_cloud => $tag_cloud );
}

1;
