#
# AUTHORS:
#	Copyright (C) 2003-2011 Opsera Limited. All rights reserved
#
#    This file is part of Opsview
#
#    Opsview is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    Opsview is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Opsview; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#
package Opsview::Web::Controller::WrapCGI;

use strict;
use warnings;
use base qw/Opsview::Web::ControllerBase::WrapCGI Opsview::Web::Utils/;

__PACKAGE__->config( cgi_base_path => '/usr/local/nagios/sbin', );

sub path_prefix {'cgi-bin'}

sub auto : Private {
    my ( $self, $c ) = @_;
    $c->stash( template => 'cgi_output' );
    return $c->forward("/authenticate");
}

##### Opsview CGI scripts

sub query_host : Path('query_host.cgi') {
    my ( $self, $c ) = @_;
    $self->cgi_to_response( $c => 'query_host.cgi' );
}

##### Nagios CGI scripts

sub avail : Path('avail.cgi') {
    my ( $self, $c ) = @_;
    $c->stash->{page_title} .= ' > ' . $c->loc("ui.nagios.title.availabilityReport");
    $self->setup_specific_page_titles($c);
    $self->cgi_to_process( $c => 'avail.cgi' );
}

sub cmd : Path('cmd.cgi') {
    my ( $self, $c ) = @_;
    my ( $host_obj, $service_obj, $hostgroup_obj );

    if ( $c->req->param("service") ) {
        $service_obj = $c->model('RuntimeDB::Service')->search(
            {   hostname    => $c->req->param("host"),
                servicename => $c->req->param("service"),
            }
        )->first;
        $host_obj = $service_obj->host_object_id;
    }
    elsif ( $c->req->param("host") ) {
        $host_obj = $c->model('RuntimeDB::Host')->search( { name => $c->req->param("host"), } )->first;
    }
    elsif ( $c->req->param("hostgroup") ) {
        $hostgroup_obj = $c->model('RuntimeDB::Hostgroup')->search( { name => $c->req->param("hostgroup"), } )->first;
    }

    my $cmd_typ = $c->req->param("cmd_typ");

    # redirect passive check submissions to our own form
    if ( $cmd_typ == 30 && $service_obj ) {
        $c->res->redirect( $c->uri_for( "/state/service/host_service", $service_obj ) );
    }
    elsif ( ( $cmd_typ == 55 || $cmd_typ == 86 ) && $host_obj ) {
        $c->res->redirect( $c->uri_for( "/state/host", $host_obj, "downtime" ) );
    }
    elsif ( $cmd_typ == 56 && $service_obj ) {
        $c->log->debug( $c->uri_for( "/state/service", $service_obj, "downtime" ) );
        $c->res->redirect( $c->uri_for( "/state/service", $service_obj, "downtime" ) );
    }
    elsif ( ( $cmd_typ == 84 || $cmd_typ == 85 ) && $hostgroup_obj ) {
        $c->log->debug( $c->uri_for( "/state/hostgroup", $hostgroup_obj, "downtime" ) );
        $c->res->redirect( $c->uri_for( "/state/hostgroup", $hostgroup_obj, "downtime" ) );
    }
    else {

        my $page_title
            = $cmd_typ == 34
            ? $c->loc("ui.nagios.title.acknowledge")
            : $c->loc("ui.nagios.title.externalCommand");

        $c->stash->{page_title} .= ' > ' . $page_title;
        $self->setup_specific_page_titles($c);

        $self->cgi_to_process( $c => 'cmd.cgi' );
    }
}

sub extinfo : Path('extinfo.cgi') {
    my ( $self, $c ) = @_;
    my $cgi_type = $c->req->param('type');

    my $page_title
        = $cgi_type == 0 ? $c->loc("ui.nagios.title.processInformation")
        : $cgi_type == 1 ? $c->loc("ui.nagios.title.detail")
        : $cgi_type == 2 ? $c->loc("ui.nagios.title.detail")
        : $cgi_type == 3 ? $c->loc("ui.nagios.title.comments")
        : $cgi_type == 4 ? $c->loc("ui.nagios.title.performanceInformation")
        : $cgi_type == 6 ? $c->loc("ui.nagios.title.scheduledDowntime")
        : $cgi_type == 7 ? $c->loc("ui.nagios.title.schedulingQueue")
        :                  '';

    if ($page_title) {
        $c->stash->{page_title} .= ' > ' . $c->loc("ui.nagios.title.status") . ' > ' . $page_title;
        $self->setup_specific_page_titles($c);
    }
    $self->cgi_to_process( $c => 'extinfo.cgi' );
}

sub histogram : Path('histogram.cgi') {
    my ( $self, $c ) = @_;
    $c->stash->{page_title} .= ' > ' . $c->loc("ui.nagios.title.alertHistogram");
    $self->setup_specific_page_titles($c);
    $self->cgi_to_process( $c => 'histogram.cgi' );
}

sub mrtg_rrd : Path('mrtg-rrd.cgi') {
    my ( $self, $c, $arg ) = @_;

    $c->stash->{page_title} .= ' > ' . $c->loc("ui.mrtg.title.networkTraffic");

    # As mrtg-rrd.cgi doesn't implement any access control, we do it here
    # NOTE: hostname could be provided as arg if parameter isnt set
    #       You must check $arg first, otherwise someone could add a ?host={allowed} to get access to a different host
    # NOTE 2: hostname is of form {ip}_{interface}. Some MRTGs (or SNMP devices) return an interface name, rather than
    # a number. Handle that in the regexp below. Similar changes required to mrtg-rrd.cgi
    # NOTE 3: There is possible problems if the hostname contains underscores, but as this is IP or dns based, it should be okay
    my $hostname;
    if ($arg) {
        ($hostname) = $arg =~ m/^(.+?)_/;
    }
    else {
        $hostname = $c->req->param("host");
    }
    unless ($hostname) {
        $c->stash( error => $c->loc("messages.noHostname") );
        $c->detach("/soft_error");
    }
    $self->setup_specific_page_titles($c);
    my $it = Opsview::Host->search( ip => $hostname );
    unless ( $it->count ) {
        $c->stash( error => $c->loc( "messages.host.notFound [_1]", $hostname ) );
        $c->detach("/soft_error");
    }

    # As mrtg uses hostname, and hostnames could be duplicated,
    # we have to make sure the user has access to every single host that uses
    # this hostname. This is potentially too restrictive, but as MRTG is being
    # superceded with NMIS, this will do for now
    my $ok = 1;
    while ( my $host = $it->next ) {
        $ok = 0 unless $c->user->has_host_access($host);
    }
    unless ($ok) {
        $c->stash( error => $c->loc( "messages.accessDeniedToHost [_1]", $hostname ) );
        $c->detach("/soft_error");
    }

    # mrtg-rrd.cgi very sensitive to URI
    # If using Opsview wrapper, will need to consider this ajax url rewrite
    #my $uri = $c->req->uri;
    #$uri =~ s|/ajax||;
    #$c->req->uri($uri);

    $self->cgi_to_response( $c => "mrtg-rrd.cgi" );
}

sub history : Path('history.cgi') {
    my ( $self, $c ) = @_;
    $c->stash->{page_title} .= ' > ' . $c->loc("ui.nagios.title.alertHistory");
    $self->setup_specific_page_titles($c);
    $self->cgi_to_process( $c => 'history.cgi' );
}

sub new_config : Path('config.cgi') {
    my ( $self, $c ) = @_;
    $c->stash->{page_title} .= ' > ' . $c->loc("ui.nagios.title.nagiosConfiguration");
    $self->cgi_to_process( $c => 'config.cgi' );
}

sub tac : Path('tac.cgi') {
    my ( $self, $c ) = @_;
    $c->stash->{page_title} .= ' > ' . $c->loc("ui.nagios.title.tacticalView");
    $self->cgi_to_process( $c => 'tac.cgi' );
}

sub outages : Path('outages.cgi') {
    my ( $self, $c ) = @_;
    $c->stash->{page_title} .= ' > ' . $c->loc("ui.nagios.title.networkOutages");
    $self->cgi_to_process( $c => 'outages.cgi' );
}

sub notifications : Path('notifications.cgi') {
    my ( $self, $c ) = @_;
    $c->stash->{page_title} .= ' > ' . $c->loc("ui.nagios.title.notifications");
    $self->setup_specific_page_titles($c);
    $self->cgi_to_process( $c => 'notifications.cgi' );
}

sub nmiscgi : Path('nmiscgi.pl') {
    my ( $self, $c ) = @_;
    $self->cgi_to_process( $c => "nmiscgi.pl" );
}

sub trends : Path('trends.cgi') {
    my ( $self, $c ) = @_;
    $c->stash->{page_title} .= ' > ' . $c->loc("ui.nagios.title.trends");
    $self->setup_specific_page_titles($c);
    $self->cgi_to_process( $c => 'trends.cgi' );
}

sub showlog : Path('showlog.cgi') {
    my ( $self, $c ) = @_;
    $c->stash->{page_title} .= ' > ' . $c->loc("ui.nagios.title.logDisplay");
    $self->cgi_to_process( $c => 'showlog.cgi' );
}

sub summary : Path('summary.cgi') {
    my ( $self, $c ) = @_;
    $c->stash->{page_title} .= ' > ' . $c->loc("ui.nagios.title.alertSummary");
    $self->cgi_to_process( $c => 'summary.cgi' );
}

sub status : Path('status.cgi') {
    my ( $self, $c ) = @_;
    $c->stash->{page_title} .= ' > ' . $c->loc("ui.nagios.title.status");
    $self->setup_specific_page_titles($c);
    $self->cgi_to_process( $c => 'status.cgi' );
}

sub statusmap : Path('statusmap.cgi') {
    my ( $self, $c ) = @_;
    $c->stash->{page_title} .= ' > ' . $c->loc("ui.nagios.title.statusMap");
    $self->cgi_to_process( $c => 'statusmap.cgi' );
}

1;
