#
# AUTHORS:
#	Copyright (C) 2003-2011 Opsera Limited. All rights reserved
#
#    This file is part of Opsview
#
#    Opsview is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    Opsview is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Opsview; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#
# This provides the base class so that you can have URLs like:
# /runtime/{type}/{id}/notifications
# /runtime/{type}/name/{name}/notifications
#
# Using by id will set in the stash objects which is a array ref with only 1 object
# Using by name could return multiple objects in the array ref
#
# Need to setup a super class with an anchor sub

package Opsview::Web::ControllerBase::Chained;

use strict;
use warnings;
use base qw(Catalyst::Controller);

__PACKAGE__->mk_accessors(qw/model_name/);

sub auto : Private {
    my ( $self, $c ) = @_;
    $c->forward("/authenticate");
}

sub common : Private {
    my ( $self, $c ) = @_;
    $c->stash( additional_template_paths => [ $c->path_to( 'root', $c->action->namespace )->stringify, $c->path_to( 'root', 'state' )->stringify ] );
}

# eg, /runtime/hostgroup/{id}/
sub by_id : PathPart('') Chained('anchor') CaptureArgs(1) {
    my ( $self, $c, $id ) = @_;
    my $o = $c->model( $self->model_name )->retrieve($id);
    unless ($o) {
        $c->stash( error => "Id $id not found" );
        $c->detach("/soft_error");
    }

    # This is probably very hacky - this should go in the host specific area of the chain
    if ( $self->model_name eq "OpsviewDB::Host" ) {
        $c->forward("/access_denied") unless $c->user->has_host_access($o);
    }
    $c->stash( objects => [$o] );
    $c->stash( object  => $o );
}

# Disable the endpoint for now
# eg, /runtime/hostgroup/*
#sub by_id_end : PathPart('') Chained('anchor') Args(1) : ActionClass('REST') {
#	my ($self, $c, $id) = @_;
#	$self->by_id($c, $id);
#}

# eg, /runtime/hostgroup/name/*/
sub by_name : PathPart('name') Chained('anchor') CaptureArgs(1) {
    my ( $self, $c, $name ) = @_;
    my $it = $c->model( $self->model_name )->search( { name => $name } );
    unless ( $it->count ) {
        $c->stash( error => "Name $name not found" );
        $c->detach("/soft_error");
    }
    $c->stash( objects => [ $it->data ] );
    $c->stash( object  => $it->first );
}

# Disable end point for now
# eg, /runtime/hostgroup/name/*
#sub by_name_end : PathPart('name') Chained('anchor') Args(1) : ActionClass('REST') {
#	my ($self, $c, $name) = @_;
#	$self->by_name($c,$name);
#}

1;
