#
# AUTHORS:
#	Copyright (C) 2003-2011 Opsera Limited. All rights reserved
#
#    This file is part of Opsview
#
#    Opsview is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    Opsview is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Opsview; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#
# Use this to allow /state/{type}/{id}/downtime

package Opsview::Web::ControllerBase::Downtime;
use base qw(Catalyst::Controller);
use Opsview::Common;
use DateTime;

sub downtime_by_id_end : PathPart('downtime') Chained('by_id') : Args(0) {
    my $self = shift;
    $self->downtime_auth(@_);
    $self->downtime_page(@_);
}

sub downtime_by_name_end : PathPart('downtime') Chained('by_name') : Args(0) {
    my $self = shift;
    $self->downtime_auth(@_);
    $self->downtime_page(@_);
}

sub downtime_by_id_chained : PathPart('downtime') Chained('by_id') : CaptureArgs(0) {
    shift->downtime_auth(@_);
}

sub downtime_by_id_chained_no_auth : PathPart('downtime') Chained('by_id') : CaptureArgs(0) {
}

sub downtime_by_name_chained : PathPart('downtime') Chained('by_name') : CaptureArgs(0) {
    shift->downtime_auth(@_);
}

sub save_downtime_by_id_chained_end : PathPart('save') : Chained('downtime_by_id_chained') : Args(0) {
    shift->save(@_);
}

sub save_downtime_by_name_chained_end : PathPart('save') : Chained('downtime_by_name_chained') : Args(0) {
    shift->save(@_);
}

sub delete_downtime_by_id_chained_end : PathPart('delete') : Chained('downtime_by_id_chained') : Args(0) {
    shift->delete(@_);
}

sub delete_downtime_by_name_chained_end : PathPart('delete') : Chained('downtime_by_name_chained') : Args(0) {
    shift->delete(@_);
}

sub delete_all_downtime_by_id_chained_end : PathPart('delete_all') : Chained('downtime_by_id_chained') : Args(0) {
    shift->delete_all(@_);
}

sub deleteall_downtime_by_name_chained_end : PathPart('delete_all') : Chained('downtime_by_name_chained') : Args(0) {
    shift->delete_all(@_);
}

sub downtime_auth : Private {
    my ( $self, $c, @args ) = @_;
    if ( !$c->stash->{object}->can_set_downtime_by( $c->user ) ) {
        delete $c->stash->{wrapper};
        $c->stash( template => "access_denied" );
        Opsview::Auditlog->create(
            {   username => $c->user->username,
                text     => $c->translate( "messages.auditlog.noAdminAccessDeniedTo [_1]", "downtime" ),
            }
        );
        $c->detach;
    }

    if ( $c->stash->{object}->my_type_is eq "service" ) {
        $c->stash->{services} = [ $c->model("RuntimeSchema::OpsviewHostServices")->find( $c->stash->{object}->id ) ];
    }
    elsif ( $c->stash->{object}->my_type_is eq "host" ) {
        $c->stash->{hosts} = [ $c->model("RuntimeSchema::OpsviewHosts")->find( $c->stash->{object}->id ) ];
    }
    else {
        $c->stash->{hostgroups} = [ $c->model("RuntimeSchema::OpsviewHostgroups")->find( $c->stash->{object}->id ) ];
    }

}

sub downtime_page : Private {
    my ( $self, $c ) = @_;
    if ( $c->req->method eq "POST" ) {
        $c->forward("save");
    }
    delete $c->stash->{wrapper};
    $c->stash( template   => "downtime" );
    $c->stash( now_dt     => DateTime->now( time_zone => "local" ) );
    $c->stash( action_uri => $c->uri_for( "/" . $c->req->path )->path );
    $c->stash->{from} = $c->req->param("from") || $c->req->referer;
    $c->stash( page_title => " > " . $c->loc("ui.state.downtime.title.scheduleDowntime") );
    push( @{ $c->stash->{stylesheets} }, 'admin.css' );
}

sub save : Private {
    my ( $self, $c ) = @_;

    $c->forward("/rest/downtime/downtime_validate");

    if ( $_ = $c->stash->{validation_errors} ) {
        $c->stash( error_message => join( "; ", @$_ ) );
        return;
    }

    $c->forward("/rest/downtime/downtime_set");

    my @all_errors = @{ $c->stash->{all_errors} };
    if (@all_errors) {
        $c->stash( error_message => $c->loc( "ui.downtime.help.errorSetting [_1]", join( "; ", @all_errors ) ) );
    }
    else {
        if ( $c->stash->{object}->my_type_is eq "service" ) {
            $c->flash( message => $c->loc( "ui.downtime.help.submittedForService [_1] [_2]", $c->stash->{object}->name, $c->stash->{object}->hostname ) );
        }
        else {
            $c->flash( message => $c->loc( "ui.downtime.help.submitted [_1]", $c->stash->{object}->name ) );
        }
        $c->res->redirect( $c->req->param("from") || $c->req->referer );
    }
}

# This needs to be overridden in more specific class
sub delete : Private {
    my ( $self, $c ) = @_;
    die("Shouldn't get here");
}

sub delete_all : Private {
    my ( $self, $c ) = @_;

    $c->forward("/rest/downtime/downtime_deletion");

    my @all_errors = @{ $c->stash->{all_errors} };
    if (@all_errors) {
        $c->stash( error_message => $c->loc( "ui.downtime.help.errorDeleting [_1]", join( "; ", @all_errors ) ) );
    }
    else {
        if ( $c->stash->{object}->my_type_is eq "service" ) {
            $c->flash( message => $c->loc( "ui.downtime.help.downtimeDeletedFor [_1]", join( "::", $c->stash->{object}->hostname, $c->stash->{object}->name ) ) );
        }
        else {
            $c->flash( message => $c->loc( "ui.downtime.help.downtimeDeletedFor [_1]", $c->stash->{object}->name ) );
        }
        $c->res->redirect( $c->req->param("from") || $c->req->referer );
    }

    if ( $c->stash->{object}->isa("Runtime::Hostgroup") ) {
        $c->res->redirect( $c->uri_for( "/status/hostgroup", $c->stash->{object}->parentid ) );
    }
    elsif ( $c->stash->{object}->isa("Runtime::Host") ) {
        $c->res->redirect( $c->uri_for( "/status/service", { host => $c->stash->{object}->name } ) );
    }
    elsif ( $c->stash->{object}->isa("Runtime::Service") ) {
        $c->res->redirect( $c->uri_for( "/status/service", { host => $c->stash->{object}->hostname } ) );
    }

}

1;
