#
# AUTHORS:
#	Copyright (C) 2003-2011 Opsera Limited. All rights reserved
#
#    This file is part of Opsview
#
#    Opsview is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    Opsview is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Opsview; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#
package Opsview::Web::ControllerBase::Info;

use strict;
use warnings;

use base qw/Catalyst::Controller/;

use Opsview::Systempreference;

use Opsview::Wiki;
use Opsview::Utils qw(escape_xml);

sub info_by_id_end : PathPart('') Chained('by_id') Args(0) {
    my $self = shift;
    $self->check_link(@_);
    $self->info(@_);
}

sub info_by_name_end : PathPart('') Chained('by_name') Args(0) {
    my $self = shift;
    $self->check_link(@_);
    $self->info(@_);
}

sub edit_by_id_end : PathPart('edit') Chained('by_id') Args(0) {
    my $self = shift;
    $self->check_link(@_);
    $self->edit(@_);
}

sub edit_by_name_end : PathPart('edit') Chained('by_name') Args(0) {
    my $self = shift;
    $self->check_link(@_);
    $self->edit(@_);
}

sub doedit_by_id_end : PathPart('doedit') Chained('by_id') Args(0) {
    my $self = shift;
    $self->check_link(@_);
    $self->doedit(@_);
}

sub doedit_by_name_end : PathPart('doedit') Chained('by_name') Args(0) {
    my $self = shift;
    $self->check_link(@_);
    $self->doedit(@_);
}

sub check_link : Private {
    my ( $self, $c ) = @_;

    my $config = $c->stash->{object}->my_type_is . '_info_url';
    if ( Opsview::Systempreference->can($config) ) {
        my $link = Opsview::Systempreference->$config;
        if ($link) {
            $c->res->redirect( $c->stash->{object}->expand_macros($link) );
            $c->detach;
        }
    }

    $c->stash->{default_info}      = 'No comments currently entered for this item.';
    $c->stash->{default_edit_info} = 'No comments currently entered for this item.  ' . 'To find out about adding URLs and formatting text ' . 'see "Formatting Help"';
}

sub info : Private {
    my ( $self, $c ) = @_;

    $c->stash->{page_title} = ucfirst( $c->stash->{object}->my_type_is ) . " " . "Information For '" . $c->stash->{object}->name . "'";

    $c->stash->{template} = "info/objectinfo";
    my $information;
    if ( $c->stash->{object}->information ) {
        $information = $c->stash->{object}->information;
    }
    if ( !$information ) {
        if ( $c->stash->{object}->can_be_changed_by( $c->user ) ) {
            $information = $c->stash->{default_edit_info};
        }
        else {
            $information = $c->stash->{default_info};
        }
    }
    $c->stash->{objectinfo} = Opsview::Wiki->convert_to_html($information);
    push( @{ $c->stash->{javascript} }, qw/ prototype.js / );
}

sub edit : Private {
    my ( $self, $c ) = @_;
    if ( $c->user_exists && $c->stash->{object}->can_be_changed_by( $c->user ) ) {
        $c->stash->{doedit} = 1;
    }
    $c->forward("info");
}

sub doedit : Private {
    my ( $self, $c ) = @_;
    my $content = $c->request->param("content");

    unless ( $c->user_exists && $c->user->has_access("ADMINACCESS") ) {
        $c->forward("info");
    }

    if ( $c->stash->{object}->information && !$content ) {
        Opsview::Auditlog->create(
            {   username => $c->user->username,
                text     => "Information for " . $c->stash->{object}->my_type_is . " " . $c->stash->{object}->name . " has been removed",
            }
        );

        # Need to get specific model, otherwise Catalyst will choose and may get different one
        my $type = $c->stash->{object}->my_type_is . "info";
        $type = ucfirst($type);
        my $info = $c->model("OpsviewDB::$type")->retrieve( $c->stash->{object}->id );

        # update object first so that cached info is expired correctly
        $c->stash->{object}->information(undef);
        $info->delete;
        $c->stash->{doedit} = 1;
    }
    else {
        Opsview::Auditlog->create(
            {   username => $c->user->username,
                text     => "Information for " . $c->stash->{object}->my_type_is . " " . $c->stash->{object}->name . " has been updated",
            }
        );

        $content = escape_xml($content);
        $c->stash->{object}->information($content);
        $c->stash->{doedit} = 0;
    }
    $c->stash->{object}->update;
    $c->res->redirect( $c->uri_for( '/info', $c->stash->{object}->my_type_is, $c->stash->{object}->id ) );
}

1;
