#
# AUTHORS:
#	Copyright (C) 2003-2011 Opsera Limited. All rights reserved
#
#    This file is part of Opsview
#
#    Opsview is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    Opsview is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Opsview; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#
package Opsview::Web::ControllerBase::REST;

use Moose;
use namespace::autoclean;
use Opsview::Utils;
use Try::Tiny;

extends 'Catalyst::Controller::REST';

__PACKAGE__->config(

    # Do not set a default - this causes problems when a web page makes a request
    # Documentation says you must set a content-type & accept header
    #'default'    => 'text/x-data-dumper',
    json_options => { relaxed => 1, },
    map          => {
        'text/html'                         => 'YAML::HTML',
        'text/xml'                          => 'XMLSerialisation',
        'text/x-yaml'                       => 'YAML',
        'text/javascript'                   => 'JSONP',
        'application/json'                  => 'JSON',
        'text/json'                         => 'JSON',
        'text/x-data-dumper'                => [ 'Data::Serializer', 'Data::Dumper' ],
        'application/x-www-form-urlencoded' => 'FormJSON',
    },
);

after 'begin' => sub {
    my ( $self, $c ) = @_;
    if ( $c->log->is_debug ) {
        my $message = "REST request: " . $c->req->method . " " . $c->uri_for( "/", $c->req->path, $c->req->query_params )->path_query;
        my $data = $c->req->data;
        if ( defined $data && ref $data eq "HASH" ) {
            $message .= " Data:" . Data::Dump::dump($data);
        }
        $c->log->debug($message);
    }
};

before 'end' => sub {
    my ( $self, $c ) = @_;

    # Convert failures from C::A::REST which are strings into JSON
    if ( $c->res->status == 400 ) {
        my $content = $c->res->body;
        if ( ref $content eq "" && length $content > 0 ) {
            $c->res->body(undef);
            $c->stash->{rest} = { message => "Error with input or output data", detail => $content };
        }
    }

    my $data = $c->stash->{rest};
    if ( defined $data && ref $data eq "HASH" ) {

        if ( $c->res->status != 200 ) {
            $c->log->info( "REST response (ERROR=" . $c->res->status . "): " . $c->req->method . " " . $c->uri_for( "/", $c->req->path, $c->req->query_params )->path_query . " Data:" . Data::Dump::dump($data) );
        }
        else {
            if ( $c->log->is_debug ) {
                $c->log->debug( "REST response (OK): " . $c->req->method . " " . $c->uri_for( "/", $c->req->path, $c->req->query_params )->path_query . " Data:" . Data::Dump::dump($data) );
            }
        }

        # Convert all values into strings - this is so JSON returns back as string values, rather than "last used" type
        try {
            $c->stash->{rest} = Opsview::Utils->convert_all_values_to_string( $data, $c->stash->{dt_formatter} );
        }
        catch {
            $c->res->status(400);
            $c->stash( "rest" => { message => "Error converting values to string", detail => $_ } );
            return;
        }
    }
};

1;
