#
# AUTHORS:
#	Copyright (C) 2003-2011 Opsera Limited. All rights reserved
#
#    This file is part of Opsview
#
#    Opsview is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    Opsview is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Opsview; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#
package Opsview::Web::ControllerBase::Reorder;

use Moose;
use namespace::autoclean;

BEGIN { extends qw/Catalyst::Controller::ActionRole/ }

__PACKAGE__->mk_accessors(
    qw/
        reorderable
        /
);

__PACKAGE__->config( reorderable => 0, );

sub reorder : Local : Does(ACL) : RequiresRole(CONFIGUREVIEW) : ACLDetachTo(/access_denied) {
    my ( $self, $c ) = @_;
    $c->forward("list");
    $c->stash( template => "reorder" );
}

sub set_order : Local {
    my ( $self, $c ) = @_;
    $c->forward("/admin/check_save_access");
    my $class = $c->stash->{model_class};
    my $dbix  = $c->stash->{is_dbix_class};

    my $priority = 1;
    foreach my $id ( $c->req->param("list[]") ) {
        if ($dbix) {
            my $o = $class->find($id);
            $o->update( { priority => $priority } );
        }
        else {
            my $o = $class->retrieve($id);
            $o->priority($priority);
            $o->update;
        }
        $priority++;
    }
    my $type = $self->title_description || $self->model_name;
    my $text = $c->translate( "messages.auditlog.reorder.newOrderFor [_1]", $type ) . ": " . join( " ", $c->req->param("list[]") );
    Opsview::Auditlog->create(
        {   username => $c->user->username,
            text     => $text,
        }
    );
    $c->res->body(" ");
}

1;
