#
# AUTHORS:
#	Copyright (C) 2003-2011 Opsera Limited. All rights reserved
#
#    This file is part of Opsview
#
#    Opsview is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    Opsview is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Opsview; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#
# Use this to allow /state/{type}/{id}/detail

package Opsview::Web::ControllerBase::State;
use warnings;
use strict;
use base qw(Catalyst::Controller);
use Opsview::Externalcommand;

sub state_by_id_end : PathPart('change') Chained('by_id') : Args(0) {
    shift->state(@_);
}

sub state_by_name_end : PathPart('change') Chained('by_name') : Args(0) {
    shift->state(@_);
}

sub apply_state_by_id_end : PathPart('apply_change') Chained('by_id') : Args(0) {
    shift->apply_state(@_);
}

sub apply_state_by_name_end : PathPart('apply_change') Chained('by_name') : Args(0) {
    shift->apply_state(@_);
}

sub get_host_service {
    my ( $self, $c ) = @_;
}

sub state : Private {
    my ( $self, $c ) = @_;
    if ( $c->req->method eq "POST" ) {
        $c->forward("apply_state");
    }
    delete $c->stash->{wrapper};
    $c->stash( template => "change" );
    $c->stash( action_uri => $c->uri_for( "/", $c->req->path ) );
    $c->stash->{from} = $c->req->param("from") || $c->req->referer;
    $c->stash( page_title => " > " . $c->loc("ui.state.service.title.submitCheckResult") );
    $c->forward("/common/nagios_states");
    push( @{ $c->stash->{stylesheets} }, 'admin.css' );
}

sub apply_state : Private {
    my ( $self, $c ) = @_;

    $c->forward( "/common/nagios_states", ["i_default"] );
    my $states_by_id = $c->stash->{nagios_states_by_id};

    $self->state_validate($c);
    my $errors = $c->stash->{validation_errors};
    my $state  = $c->req->param("state");
    push @$errors, $c->loc("messages.state.noState") unless defined $state;
    if (@$errors) {
        $c->stash( error_message => $errors );
        Opsview::Auditlog->create(
            {   username => $c->user->username,
                text     => $c->translate( "messages.auditlog.submitServiceCheck.failed [_1]", join( "; ", @$errors ), )
            }
        );
    }
    else {
        my $comment = $c->req->param("comment");
        $comment =~ s/<//g;
        $comment =~ s/>//g;
        $comment =~ s/;//g;
        $comment ||= $c->loc( "messages.submitServiceCheck.submittedBy [_1]", $c->user->name );
        my $command = new Opsview::Externalcommand;
        $command->command("PROCESS_SERVICE_CHECK_RESULT");
        $command->args( join( ";", $c->stash->{object}->host_object_id->name, $c->stash->{object}->name, $state, $comment, ) );

        # Submitting a result is special:
        #  if on master, send to master,
        #  if on slave, send to all slaves (non-relevant ones will ignore)
        # If you send to all, then master will get two results
        # monitored_by is a column, not an object
        my $result;
        Opsview::Auditlog->create(
            {   username => $c->user->username,
                text     => $c->translate( "messages.auditlog.submittingServiceCheckResultOnAs [_1] [_2] [_3] [_4]", $c->stash->{object}->name, $c->stash->{object}->host_object_id->name, $states_by_id->{$state}, $comment, )
            }
        );
        if ( $c->stash->{object}->host_object_id->monitored_by == 1 ) {
            eval { $result = $command->send_to_master };
        }
        else {
            eval { $result = $command->send_to_slaves };
        }
        if ( !$@ ) {
            if (   $c->req->param("from") !~ m/extinfo.cgi/
                && $c->req->referer !~ m/extinfo.cgi/ )
            {
                $c->flash( message => $c->loc( "ui.service.submitCheckResult.submitted [_1] [_2]", $c->stash->{object}->name, $c->stash->{object}->host_object_id->name ) );
            }
            $c->res->redirect( $c->req->param("from") || $c->req->referer );
        }
        else {
            my $error = $@;
            $c->stash( error_message => $error );
            Opsview::Auditlog->create(
                {   username => $c->user->username,
                    text     => $c->translate( "messages.auditlog.submitCheckResult.failed [_1]", $error )
                }
            );
        }
    }
}

sub state_validate : Private {
    my ( $self, $c ) = @_;
    my @errors;

    unless ( $c->user->can_change_service( $c->stash->{object} ) ) {
        push( @errors, $c->loc("messages.access.noAuthToChangeService") );
    }

    $c->stash( validation_errors => \@errors );
}

1;
