#
# AUTHORS:
#       Copyright (C) 2003-2011 Opsera Limited. All rights reserved
#
#    This file is part of Opsview
#
#    Opsview is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    Opsview is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Opsview; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#
package Opsview::Web::View::Download::Excel;

use strict;
use warnings;
use base qw( Catalyst::View );

use Catalyst::Exception;
use Spreadsheet::WriteExcel;

=head1 NAME

Opsview::Web::View::Download::Excel - Catalyst View

=head1 DESCRIPTION

Catalyst View for downloading data as an Excel Spreadsheet.

=head1 AUTHOR

Tristan Aubrey-Jones for Opsera LTD.

=cut

__PACKAGE__->config( 'stash_key' => 'excel' );

sub process {
    my $self = shift;
    my ($c) = @_;

    my $content = $self->render( $c, $c->stash );

    $c->res->headers->header( "Content-Type" => "application/x-msexcel" );
    $c->res->body($content);
}

sub render {
    my $self = shift;
    my ( $c, $args ) = @_;

    my $data;
    my $stash_key = $self->config->{'stash_key'};

    if (   defined( $args->{$stash_key} )
        && ref( $args->{$stash_key} ) =~ /HASH/
        && defined( $args->{$stash_key}{data} )
        && $args->{$stash_key}{data} =~ /ARRAY/ )
    {
        $data = $args->{$stash_key}{data};
    }

    # Open lexical file handle (Requires perl 5.8 or later)
    open my $fh, '>', \my $content or die "Failed to open filehandle: $!";

    # Create a new Excel workbook
    my $workbook = Spreadsheet::WriteExcel->new($fh);

    # Add a worksheet
    my $worksheet = $workbook->add_worksheet();

    #  Add and define a format
    my $format = $workbook->add_format();    # Add a format
    $format->set_bold();
    $format->set_color('red');
    $format->set_align('center');

    # Write 2D array to spreadsheet
    $worksheet->write_col( 0, 0, $data );

    # Close spreadsheet
    $workbook->close();

    return $content;
}

1;

__END__
