# AUTHORS:
#  Copyright (C) 2003-2011 Opsera Limited. All rights reserved
#
#    This file is part of Opsview
#
#    Opsview is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    Opsview is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Opsview; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#
# Extra functionality required by Opsview

package Template::Plugin::Opsview;
use base 'Template::Plugin';
use strict;
use warnings;
use Template::Exception;

our $VERSION   = 0.01;
our $EXCEPTION = 'Template::Exception';
our $AUTOLOAD;

sub new {
    my ( $class, $context, $params ) = @_;
    my $self = bless { $params ? %$params : (), }, $class;
    return $self;
}

sub rand {
    return int rand 100;
}

{
    my %seen_ids;

    sub unique_id {
        my ( $self, $id ) = @_;

        return $seen_ids{$id}++;
    }

    sub reset_unique {
        %seen_ids = ();
    }
}

use Opsview::Utils::Time;

sub seconds_to_jira {
    my $self = shift;
    Opsview::Utils::Time->seconds_to_jira_duration(shift);
}

1;

__END__

=head1 NAME

Template::Plugin::Opsview - extra functionality required by Opsview

=head1 SYNOPSIS

    [% USE Opsview %]

    # Generate a random number
    [% Opsview.rand %]

=head1 DESCRIPTION

Extra functionality required by Opsview

=head1 METHODS

=over

=item rand

Return a random integer between 0 and 100

=item unique_id( id )

Returned a unique number (starting from 0) based on how many times the 
scalar 'id' has previously been seen

=back
